@@ -24,7 +24,7 @@ import (
 	"k8s.io/kubectl/pkg/util/i18n"
 )
 
-var toolboxShort = i18n.T(`Miscellaneous, infrequently used commands.`)
+var toolboxShort = i18n.T(`Miscellaneous, experimental, or infrequently used commands.`)
 
 func NewCmdToolbox(f commandutils.Factory, out io.Writer) *cobra.Command {
 	cmd := &cobra.Command{
@@ -35,6 +35,7 @@ func NewCmdToolbox(f commandutils.Factory, out io.Writer) *cobra.Command {
 	cmd.AddCommand(NewCmdToolboxDump(f, out))
 	cmd.AddCommand(NewCmdToolboxTemplate(f, out))
 	cmd.AddCommand(NewCmdToolboxInstanceSelector(f, out))
+	cmd.AddCommand(NewCmdToolboxAddons(out))
 
 	return cmd
 }
