@@ -124,7 +124,7 @@ func (h *HookBuilder) buildSystemdService(name string, hook *kops.HookSpec) (*no
 		case nil:
 			unit.SetSection("Service", hook.Manifest)
 		default:
-			switch h.Cluster.Spec.ContainerRuntime {
+			switch h.NodeupConfig.ContainerRuntime {
 			case "containerd":
 				if err := h.buildContainerdService(unit, hook, name); err != nil {
 					return nil, err
@@ -134,7 +134,7 @@ func (h *HookBuilder) buildSystemdService(name string, hook *kops.HookSpec) (*no
 					return nil, err
 				}
 			default:
-				return nil, fmt.Errorf("unknown container runtime %q", h.Cluster.Spec.ContainerRuntime)
+				return nil, fmt.Errorf("unknown container runtime %q", h.NodeupConfig.ContainerRuntime)
 			}
 		}
 		definition = s(unit.Render())
