@@ -184,7 +184,7 @@ func (t *ProtokubeBuilder) ProtokubeFlags() (*ProtokubeFlags, error) {
 
 	f.ClusterID = fi.PtrTo(t.NodeupConfig.ClusterName)
 
-	zone := t.Cluster.Spec.DNSZone
+	zone := t.NodeupConfig.DNSZone
 	if zone != "" {
 		if strings.Contains(zone, ".") {
 			// match by name
@@ -202,15 +202,15 @@ func (t *ProtokubeBuilder) ProtokubeFlags() (*ProtokubeFlags, error) {
 	if t.UsesLegacyGossip() {
 		klog.Warningf("using (legacy) gossip DNS", t.NodeupConfig.ClusterName)
 		f.Gossip = fi.PtrTo(true)
-		if t.Cluster.Spec.GossipConfig != nil {
-			f.GossipProtocol = t.Cluster.Spec.GossipConfig.Protocol
-			f.GossipListen = t.Cluster.Spec.GossipConfig.Listen
-			f.GossipSecret = t.Cluster.Spec.GossipConfig.Secret
+		if t.NodeupConfig.GossipConfig != nil {
+			f.GossipProtocol = t.NodeupConfig.GossipConfig.Protocol
+			f.GossipListen = t.NodeupConfig.GossipConfig.Listen
+			f.GossipSecret = t.NodeupConfig.GossipConfig.Secret
 
-			if t.Cluster.Spec.GossipConfig.Secondary != nil {
-				f.GossipProtocolSecondary = t.Cluster.Spec.GossipConfig.Secondary.Protocol
-				f.GossipListenSecondary = t.Cluster.Spec.GossipConfig.Secondary.Listen
-				f.GossipSecretSecondary = t.Cluster.Spec.GossipConfig.Secondary.Secret
+			if t.NodeupConfig.GossipConfig.Secondary != nil {
+				f.GossipProtocolSecondary = t.NodeupConfig.GossipConfig.Secondary.Protocol
+				f.GossipListenSecondary = t.NodeupConfig.GossipConfig.Secondary.Listen
+				f.GossipSecretSecondary = t.NodeupConfig.GossipConfig.Secondary.Secret
 			}
 		}
 
