@@ -30,7 +30,7 @@ var _ fi.NodeupModelBuilder = &WarmPoolBuilder{}
 
 func (b *WarmPoolBuilder) Build(c *fi.NodeupModelBuilderContext) error {
 	// Check if the cloud provider is AWS
-	if b.CloudProvider != kops.CloudProviderAWS {
+	if b.CloudProvider() != kops.CloudProviderAWS {
 		return nil
 	}
 
@@ -39,7 +39,7 @@ func (b *WarmPoolBuilder) Build(c *fi.NodeupModelBuilderContext) error {
 		for _, image := range b.NodeupConfig.WarmPoolImages {
 			c.AddTask(&nodetasks.PullImageTask{
 				Name:    image,
-				Runtime: b.Cluster.Spec.ContainerRuntime,
+				Runtime: b.NodeupConfig.ContainerRuntime,
 			})
 		}
 	}
