@@ -21,6 +21,7 @@ import (
 	"strings"
 
 	"k8s.io/kops/upup/pkg/fi/utils"
+	"sigs.k8s.io/yaml"
 )
 
 // ParseInstanceGroupRole converts a string to an InstanceGroupRole.
@@ -33,10 +34,10 @@ func ParseInstanceGroupRole(input string, lenient bool) (InstanceGroupRole, bool
 		// Accept pluralized "bastions" for "bastion"
 		findRole = strings.TrimSuffix(findRole, "s")
 	}
+	findRole = strings.Replace(findRole, "controlplane", "control-plane", 1)
 
 	for _, role := range AllInstanceGroupRoles {
-		s := string(role)
-		s = strings.ToLower(s)
+		s := role.ToLowerString()
 		if lenient {
 			s = strings.TrimSuffix(s, "s")
 		}
@@ -44,6 +45,11 @@ func ParseInstanceGroupRole(input string, lenient bool) (InstanceGroupRole, bool
 			return role, true
 		}
 	}
+
+	if lenient && strings.ToLower(findRole) == "master" {
+		return InstanceGroupRoleControlPlane, true
+	}
+
 	return "", false
 }
 
@@ -55,7 +61,7 @@ func ParseRawYaml(data []byte, dest interface{}) error {
 	configString = strings.TrimSpace(configString)
 
 	if configString != "" {
-		err := utils.YamlUnmarshal([]byte(configString), dest)
+		err := yaml.Unmarshal([]byte(configString), dest, yaml.DisallowUnknownFields)
 		if err != nil {
 			return fmt.Errorf("error parsing configuration: %v", err)
 		}
