@@ -27,21 +27,11 @@ func gceValidateCluster(c *kops.Cluster) field.ErrorList {
 
 	fieldSpec := field.NewPath("spec")
 
-	region := ""
 	for i, subnet := range c.Spec.Networking.Subnets {
 		f := fieldSpec.Child("networking", "subnets").Index(i)
 		if subnet.Zone != "" {
 			allErrs = append(allErrs, field.Invalid(f.Child("zone"), subnet.Zone, "zones should not be specified for GCE subnets, as GCE subnets are regional"))
 		}
-		if subnet.Region == "" {
-			allErrs = append(allErrs, field.Required(f.Child("region"), "region must be specified for GCE subnets"))
-		} else {
-			if region == "" {
-				region = subnet.Region
-			} else if region != subnet.Region {
-				allErrs = append(allErrs, field.Forbidden(f.Child("region"), "clusters cannot span GCE regions"))
-			}
-		}
 	}
 
 	return allErrs
