@@ -44,7 +44,12 @@ type Config struct {
 	// Packages specifies additional packages to be installed.
 	Packages []string `json:"packages,omitempty"`
 
-	// Manifests for running etcd
+	// ConfigStore configures the stores that nodes use to get their configuration when they don't use kops-controller.
+	ConfigStore *kops.ConfigStoreSpec `json:"configStore,omitempty"`
+
+	// EtcdClusterNames are the names of the etcd clusters.
+	EtcdClusterNames []string `json:",omitempty"`
+	// EtcdManifests are the manifests for running etcd.
 	EtcdManifests []string `json:"etcdManifests,omitempty"`
 
 	// CAs are the CA certificates to trust.
@@ -70,9 +75,9 @@ type Config struct {
 	UsesKubenet bool `json:",omitempty"`
 	// NTPUnmanaged is true when NTP is not managed by kOps.
 	NTPUnmanaged bool `json:",omitempty"`
-	// SysctlParameters will configure kernel parameters using sysctl(8). When
-	// specified, each parameter must follow the form variable=value, the way
-	// it would appear in sysctl.conf.
+	// ServiceNodePortRange is the service NodePort range.
+	ServiceNodePortRange string `json:",omitempty"`
+	// SysctlParameters will configure kernel parameters using sysctl(8).
 	SysctlParameters []string `json:",omitempty"`
 	// UpdatePolicy determines the policy for applying upgrades automatically.
 	UpdatePolicy string
@@ -92,6 +97,12 @@ type Config struct {
 
 	// APIServerConfig is additional configuration for nodes running an APIServer.
 	APIServerConfig *APIServerConfig `json:",omitempty"`
+	// ControlPlaneConfig is additional configuration for control-plane nodes.
+	ControlPlaneConfig *ControlPlaneConfig `json:",omitempty"`
+	// GossipConfig is configuration for gossip DNS.
+	GossipConfig *kops.GossipConfig `json:",omitempty"`
+	// DNSZone is the DNS zone we should use when configuring DNS.
+	DNSZone string `json:",omitempty"`
 	// NvidiaGPU contains the configuration for nvidia
 	NvidiaGPU *kops.NvidiaGPUConfig `json:",omitempty"`
 
@@ -110,11 +121,26 @@ type Config struct {
 	// WarmPoolImages are the container images to pre-pull during instance pre-initialization
 	WarmPoolImages []string `json:"warmPoolImages,omitempty"`
 
+	// Azure-specific
+	// AzureLocation is the location of the resource group that the cluster is deployed in.
+	AzureLocation string `json:",omitempty"`
+	// AzureSubscriptionID is the ID of the Azure Subscription that the cluster is deployed in.
+	AzureSubscriptionID string `json:",omitempty"`
+	// AzureTenantID is the ID of the tenant that the cluster is deployed in.
+	AzureTenantID string `json:",omitempty"`
+	// AzureResourceGroup is the name of the resource group that the cluster is deployed in.
+	AzureResourceGroup string `json:",omitempty"`
+	// AzureRouteTableName is the name of the route table attached to the subnet that the cluster is deployed in.
+	AzureRouteTableName string `json:",omitempty"`
+
 	// GCE-specific
 	Multizone          *bool   `json:"multizone,omitempty"`
 	NodeTags           *string `json:"nodeTags,omitempty"`
 	NodeInstancePrefix *string `json:"nodeInstancePrefix,omitempty"`
 
+	// Openstack-specific
+	Openstack *kops.OpenstackSpec `json:",omitempty"`
+
 	// Discovery methods
 	UsesLegacyGossip bool `json:"usesLegacyGossip"`
 	UsesNoneDNS      bool `json:"usesNoneDNS"`
@@ -168,8 +194,12 @@ type StaticManifest struct {
 
 // APIServerConfig is additional configuration for nodes running an APIServer.
 type APIServerConfig struct {
+	// ClusterDNSDomain is the suffix we use for internal DNS names (normally cluster.local).
+	ClusterDNSDomain string
 	// KubeAPIServer is a copy of the KubeAPIServerConfig from the cluster spec.
 	KubeAPIServer *kops.KubeAPIServerConfig
+	// API controls how the Kubernetes API is exposed.
+	API kops.APISpec
 	// Authentication is a copy of the AuthenticationSpec from the cluster spec.
 	Authentication *kops.AuthenticationSpec `json:",omitempty"`
 	// EncryptionConfigSecretHash is a hash of the encryptionconfig secret.
@@ -180,6 +210,14 @@ type APIServerConfig struct {
 	ServiceAccountPublicKeys string
 }
 
+// ControlPlaneConfig is additional configuration for control-plane nodes.
+type ControlPlaneConfig struct {
+	// KubeControllerManager is the configuration for the kube-controller-manager.
+	KubeControllerManager kops.KubeControllerManagerConfig
+	// KubeScheduler is the configuration for the kube-scheduler.
+	KubeScheduler kops.KubeSchedulerConfig
+}
+
 func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Config, *BootConfig) {
 	role := instanceGroup.Spec.Role
 
@@ -195,15 +233,15 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 			NonMasqueradeCIDR:     cluster.Spec.Networking.NonMasqueradeCIDR,
 			ServiceClusterIPRange: cluster.Spec.Networking.ServiceClusterIPRange,
 		},
-		UsesKubenet:      cluster.Spec.Networking.UsesKubenet(),
-		SysctlParameters: instanceGroup.Spec.SysctlParameters,
-		VolumeMounts:     instanceGroup.Spec.VolumeMounts,
-		FileAssets:       append(filterFileAssets(instanceGroup.Spec.FileAssets, role), filterFileAssets(cluster.Spec.FileAssets, role)...),
-		Hooks:            [][]kops.HookSpec{igHooks, clusterHooks},
-		ContainerRuntime: cluster.Spec.ContainerRuntime,
-		Docker:           cluster.Spec.Docker,
-		UsesLegacyGossip: cluster.UsesLegacyGossip(),
-		UsesNoneDNS:      cluster.UsesNoneDNS(),
+		UsesKubenet:          cluster.Spec.Networking.UsesKubenet(),
+		ServiceNodePortRange: cluster.Spec.KubeAPIServer.ServiceNodePortRange,
+		VolumeMounts:         instanceGroup.Spec.VolumeMounts,
+		FileAssets:           append(filterFileAssets(instanceGroup.Spec.FileAssets, role), filterFileAssets(cluster.Spec.FileAssets, role)...),
+		Hooks:                [][]kops.HookSpec{igHooks, clusterHooks},
+		ContainerRuntime:     cluster.Spec.ContainerRuntime,
+		Docker:               cluster.Spec.Docker,
+		UsesLegacyGossip:     cluster.UsesLegacyGossip(),
+		UsesNoneDNS:          cluster.UsesNoneDNS(),
 	}
 
 	bootConfig := BootConfig{
@@ -241,6 +279,15 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 		}
 	}
 
+	if cluster.Spec.CloudProvider.Azure != nil {
+		config.AzureLocation = cluster.Spec.Networking.Subnets[0].Region
+		config.AzureSubscriptionID = cluster.Spec.CloudProvider.Azure.SubscriptionID
+		config.AzureTenantID = cluster.Spec.CloudProvider.Azure.TenantID
+		config.AzureResourceGroup = cluster.AzureResourceGroupName()
+		config.AzureRouteTableName = cluster.Spec.CloudProvider.Azure.RouteTableName
+		config.Networking.NetworkID = cluster.Spec.Networking.NetworkID
+	}
+
 	if cluster.Spec.CloudProvider.GCE != nil {
 		gce := cluster.Spec.CloudProvider.GCE
 		config.Multizone = gce.Multizone
@@ -248,6 +295,8 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 		config.NodeInstancePrefix = gce.NodeInstancePrefix
 	}
 
+	config.Openstack = cluster.Spec.CloudProvider.Openstack
+
 	if instanceGroup.Spec.UpdatePolicy != nil {
 		config.UpdatePolicy = *instanceGroup.Spec.UpdatePolicy
 	} else if cluster.Spec.UpdatePolicy != nil {
@@ -297,7 +346,12 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 
 	if instanceGroup.HasAPIServer() {
 		config.APIServerConfig = &APIServerConfig{
-			KubeAPIServer: cluster.Spec.KubeAPIServer,
+			ClusterDNSDomain: cluster.Spec.ClusterDNSDomain,
+			KubeAPIServer:    cluster.Spec.KubeAPIServer,
+			API: kops.APISpec{
+				PublicName:     cluster.Spec.API.PublicName,
+				AdditionalSANs: cluster.Spec.API.AdditionalSANs,
+			},
 		}
 		if cluster.Spec.Authentication != nil {
 			config.APIServerConfig.Authentication = cluster.Spec.Authentication
@@ -306,12 +360,54 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 				config.APIServerConfig.Authentication.AWS = &kops.AWSAuthenticationSpec{}
 			}
 		}
+		if cluster.Spec.API.DNS != nil {
+			config.APIServerConfig.API.DNS = &kops.DNSAccessSpec{}
+		}
+		if cluster.Spec.API.LoadBalancer != nil && cluster.Spec.API.LoadBalancer.UseForInternalAPI {
+			config.APIServerConfig.API.LoadBalancer = &kops.LoadBalancerAccessSpec{UseForInternalAPI: true}
+		}
+	}
+
+	if instanceGroup.HasAPIServer() || !model.UseKopsControllerForNodeConfig(cluster) {
+		config.ConfigStore = &kops.ConfigStoreSpec{
+			Keypairs: cluster.Spec.ConfigStore.Keypairs,
+			Secrets:  cluster.Spec.ConfigStore.Secrets,
+		}
 	}
 
 	if instanceGroup.HasAPIServer() || cluster.UsesLegacyGossip() {
 		config.Networking.EgressProxy = cluster.Spec.Networking.EgressProxy
 	}
 
+	if instanceGroup.IsControlPlane() || cluster.UsesLegacyGossip() {
+		config.DNSZone = cluster.Spec.DNSZone
+	}
+
+	if cluster.UsesLegacyGossip() {
+		config.GossipConfig = cluster.Spec.GossipConfig
+	}
+
+	if instanceGroup.IsControlPlane() {
+		config.ControlPlaneConfig = &ControlPlaneConfig{
+			KubeControllerManager: *cluster.Spec.KubeControllerManager,
+			KubeScheduler:         *cluster.Spec.KubeScheduler,
+		}
+	}
+
+	if len(instanceGroup.Spec.SysctlParameters) > 0 {
+		config.SysctlParameters = append(config.SysctlParameters,
+			"# Custom sysctl parameters from instance group spec",
+			"")
+		config.SysctlParameters = append(config.SysctlParameters, instanceGroup.Spec.SysctlParameters...)
+	}
+
+	if len(cluster.Spec.SysctlParameters) > 0 {
+		config.SysctlParameters = append(config.SysctlParameters,
+			"# Custom sysctl parameters from cluster spec",
+			"")
+		config.SysctlParameters = append(config.SysctlParameters, cluster.Spec.SysctlParameters...)
+	}
+
 	return &config, &bootConfig
 }
 
