@@ -42,6 +42,7 @@ import (
 
 // AssetBuilder discovers and remaps assets.
 type AssetBuilder struct {
+	vfsContext     *vfs.VFSContext
 	ImageAssets    []*ImageAsset
 	FileAssets     []*FileAsset
 	AssetsLocation *kops.AssetsSpec
@@ -101,8 +102,9 @@ type FileAsset struct {
 }
 
 // NewAssetBuilder creates a new AssetBuilder.
-func NewAssetBuilder(assets *kops.AssetsSpec, kubernetesVersion string, getAssets bool) *AssetBuilder {
+func NewAssetBuilder(vfsContext *vfs.VFSContext, assets *kops.AssetsSpec, kubernetesVersion string, getAssets bool) *AssetBuilder {
 	a := &AssetBuilder{
+		vfsContext:     vfsContext,
 		AssetsLocation: assets,
 		GetAssets:      getAssets,
 	}
@@ -227,7 +229,7 @@ func (a *AssetBuilder) RemapImage(image string) (string, error) {
 
 	digest, err := crane.Digest(image, crane.WithAuthFromKeychain(authn.DefaultKeychain))
 	if err != nil {
-		klog.Warningf("failed to digest image %q", image)
+		klog.Warningf("failed to digest image %q: %s", image, err)
 		return image, nil
 	}
 
@@ -332,11 +334,11 @@ func (a *AssetBuilder) findHash(file *FileAsset) (*hashing.Hash, error) {
 			Steps:    backoffSteps,
 		}
 
-		for _, ext := range []string{".sha256", ".sha1"} {
-			for _, mirror := range mirrors.FindUrlMirrors(u.String()) {
+		for _, ext := range []string{".sha256", ".sha256sum"} {
+			for _, mirror := range mirrors.FindURLMirrors(u.String()) {
 				hashURL := mirror + ext
 				klog.V(3).Infof("Trying to read hash fie: %q", hashURL)
-				b, err := vfs.Context.ReadFile(hashURL, vfs.WithBackoff(backoff))
+				b, err := a.vfsContext.ReadFile(hashURL, vfs.WithBackoff(backoff))
 				if err != nil {
 					// Try to log without being too alarming - issue #7550
 					klog.V(2).Infof("Unable to read hash file %q: %v", hashURL, err)
