@@ -57,8 +57,6 @@ var (
 	ExperimentalClusterDNS = new("ExperimentalClusterDNS", Bool(false))
 	// GoogleCloudBucketACL means the ACL will be set on a bucket when using GCS
 	GoogleCloudBucketACL = new("GoogleCloudBucketAcl", Bool(false))
-	// SpecOverrideFlag allows setting spec values on create
-	SpecOverrideFlag = new("SpecOverrideFlag", Bool(true))
 	// Spotinst toggles the use of Spotinst integration.
 	Spotinst = new("Spotinst", Bool(false))
 	// SpotinstOcean toggles the use of Spotinst Ocean instance group implementation.
@@ -83,8 +81,6 @@ var (
 	UseAddonOperators = new("UseAddonOperators", Bool(false))
 	// TerraformManagedFiles enables rendering managed files into the Terraform configuration.
 	TerraformManagedFiles = new("TerraformManagedFiles", Bool(true))
-	// Karpenter enables karpenter-managed Instance Groups
-	Karpenter = new("Karpenter", Bool(false))
 	// ImageDigest remaps all manifests with image digests
 	ImageDigest = new("ImageDigest", Bool(true))
 	// Scaleway toggles the Scaleway Cloud support.
@@ -96,6 +92,8 @@ var (
 	// - the feature won't do anything when the node OS does not support SELinux.
 	// TODO(jsafrane): add to all CSI drivers installed by kops.
 	SELinuxMount = new("SELinuxMount", Bool(false))
+	// DO Terraform toggles the DO terraform support.
+	DOTerraform = new("DOTerraform", Bool(false))
 )
 
 // FeatureFlag defines a feature flag
