@@ -51,7 +51,10 @@ func buildNodeInstanceGroup(subnets ...string) *kops.InstanceGroup {
 func TestRootVolumeOptimizationFlag(t *testing.T) {
 	cluster := buildMinimalCluster()
 	ig := buildNodeInstanceGroup("subnet-us-test-1a")
-	ig.Spec.RootVolumeOptimization = fi.PtrTo(true)
+	if ig.Spec.RootVolume == nil {
+		ig.Spec.RootVolume = &kops.InstanceRootVolumeSpec{}
+	}
+	ig.Spec.RootVolume.Optimization = fi.PtrTo(true)
 
 	k := [][]byte{}
 	k = append(k, []byte(sshPublicKeyEntry))
@@ -69,13 +72,17 @@ func TestRootVolumeOptimizationFlag(t *testing.T) {
 		},
 		BootstrapScriptBuilder: &model.BootstrapScriptBuilder{
 			Lifecycle: fi.LifecycleSync,
-			Cluster: &kops.Cluster{
-				Spec: kops.ClusterSpec{
-					CloudProvider: kops.CloudProviderSpec{
-						AWS: &kops.AWSSpec{},
+			KopsModelContext: &model.KopsModelContext{
+				IAMModelContext: iam.IAMModelContext{
+					Cluster: &kops.Cluster{
+						Spec: kops.ClusterSpec{
+							CloudProvider: kops.CloudProviderSpec{
+								AWS: &kops.AWSSpec{},
+							},
+							Networking:        kops.NetworkingSpec{},
+							KubernetesVersion: "1.20.0",
+						},
 					},
-					Networking:        kops.NetworkingSpec{},
-					KubernetesVersion: "1.20.0",
 				},
 			},
 		},
@@ -181,7 +188,6 @@ func TestAPIServerAdditionalSecurityGroupsWithNLB(t *testing.T) {
 				InstanceGroups:  igs,
 			},
 			Lifecycle: fi.LifecycleSync,
-			Cluster:   cluster,
 		},
 		Cluster: cluster,
 	}
