@@ -127,6 +127,14 @@ const (
 	// InstanceGroupLabelRestrictScaleDown is the metadata label used on the
 	// instance group to specify whether the scale-down activities should be restricted.
 	SpotInstanceGroupLabelRestrictScaleDown = "spotinst.io/restrict-scale-down"
+
+	// SpotClusterLabelSpreadNodesBy is the cloud  label used on the
+	// cluster spec to specify how Ocean will spread the nodes across markets by this value
+	SpotClusterLabelSpreadNodesBy = "spotinst.io/strategy-cluster-spread-nodes-by"
+
+	// SpotClusterLabelStrategyClusterOrientationAvailabilityVsCost is the metadata label used on the
+	// instance group to specify how to optimize towards  continuity and/or cost-effective infrastructure
+	SpotClusterLabelStrategyClusterOrientationAvailabilityVsCost = "spotinst.io/strategy-cluster-orientation-availability-vs-cost"
 )
 
 // SpotInstanceGroupModelBuilder configures SpotInstanceGroup objects
@@ -199,9 +207,9 @@ func (b *SpotInstanceGroupModelBuilder) buildElastigroup(c *fi.CloudupModelBuild
 	}
 
 	// Cloud config.
-	if cfg := b.Cluster.Spec.CloudConfig; cfg != nil {
-		group.Product = cfg.SpotinstProduct
-		group.Orientation = cfg.SpotinstOrientation
+	if aws := b.Cluster.Spec.CloudProvider.AWS; aws != nil {
+		group.Product = aws.SpotinstProduct
+		group.Orientation = aws.SpotinstOrientation
 	}
 
 	// Strategy.
@@ -324,6 +332,9 @@ func (b *SpotInstanceGroupModelBuilder) buildElastigroup(c *fi.CloudupModelBuild
 		group.AutoScalerOpts.Taints = nil
 	}
 
+	// Instance Metadata Options
+	group.InstanceMetadataOptions = b.buildInstanceMetadataOptions(ig)
+
 	klog.V(4).Infof("Adding task: Elastigroup/%s", fi.ValueOf(group.Name))
 	c.AddTask(group)
 
@@ -370,6 +381,15 @@ func (b *SpotInstanceGroupModelBuilder) buildOcean(c *fi.CloudupModelBuilderCont
 
 	klog.V(4).Infof("Detected default launch spec: %q", b.AutoscalingGroupName(ig))
 
+	for k, v := range b.Cluster.Labels {
+		switch k {
+		case SpotClusterLabelSpreadNodesBy:
+			ocean.SpreadNodesBy = fi.PtrTo(v)
+		case SpotClusterLabelStrategyClusterOrientationAvailabilityVsCost:
+			ocean.AvailabilityVsCost = fi.PtrTo(string(spotinsttasks.NormalizeClusterOrientation(&v)))
+		}
+	}
+
 	// Image.
 	ocean.ImageID = fi.PtrTo(ig.Spec.Image)
 
@@ -452,6 +472,9 @@ func (b *SpotInstanceGroupModelBuilder) buildOcean(c *fi.CloudupModelBuilderCont
 		ocean.AutoScalerOpts.Headroom = nil
 	}
 
+	// Instance Metadata Options
+	ocean.InstanceMetadataOptions = b.buildInstanceMetadataOptions(ig)
+
 	if !fi.ValueOf(ocean.UseAsTemplateOnly) {
 		// Capacity.
 		ocean.MinSize = fi.PtrTo(int64(0))
@@ -545,14 +568,14 @@ func (b *SpotInstanceGroupModelBuilder) buildLaunchSpec(c *fi.CloudupModelBuilde
 
 	// Capacity.
 	minSize, maxSize := b.buildCapacity(ig)
-	if fi.ValueOf(ocean.UseAsTemplateOnly) {
-		launchSpec.MinSize = minSize
-		launchSpec.MaxSize = maxSize
-	} else {
+	if !fi.ValueOf(ocean.UseAsTemplateOnly) {
 		ocean.MinSize = fi.PtrTo(fi.ValueOf(ocean.MinSize) + fi.ValueOf(minSize))
 		ocean.MaxSize = fi.PtrTo(fi.ValueOf(ocean.MaxSize) + fi.ValueOf(maxSize))
 	}
 
+	launchSpec.MinSize = minSize
+	launchSpec.MaxSize = maxSize
+
 	// User data.
 	if ig.Name == igOcean.Name && !featureflag.SpotinstOceanTemplate.Enabled() {
 		launchSpec.UserData = ocean.UserData
@@ -621,6 +644,9 @@ func (b *SpotInstanceGroupModelBuilder) buildLaunchSpec(c *fi.CloudupModelBuilde
 		}
 	}
 
+	//  Instance Metadata Options
+	launchSpec.InstanceMetadataOptions = b.buildInstanceMetadataOptions(ig)
+
 	klog.V(4).Infof("Adding task: LaunchSpec/%s", fi.ValueOf(launchSpec.Name))
 	c.AddTask(launchSpec)
 
@@ -640,9 +666,7 @@ func (b *SpotInstanceGroupModelBuilder) buildSecurityGroups(c *fi.CloudupModelBu
 			Name:      fi.PtrTo(id),
 			Shared:    fi.PtrTo(true),
 		}
-		if err := c.EnsureTask(sg); err != nil {
-			return nil, err
-		}
+		c.EnsureTask(sg)
 		securityGroups = append(securityGroups, sg)
 	}
 
@@ -709,56 +733,51 @@ func (b *SpotInstanceGroupModelBuilder) buildPublicIPOpts(ig *kops.InstanceGroup
 func (b *SpotInstanceGroupModelBuilder) buildRootVolumeOpts(ig *kops.InstanceGroup) (*spotinsttasks.RootVolumeOpts, error) {
 	opts := new(spotinsttasks.RootVolumeOpts)
 
-	// Optimization.
-	{
-		if fi.ValueOf(ig.Spec.RootVolumeOptimization) {
-			opts.Optimization = ig.Spec.RootVolumeOptimization
-		}
-	}
-
-	// Encryption.
-	{
-		if fi.ValueOf(ig.Spec.RootVolumeEncryption) {
-			opts.Encryption = ig.Spec.RootVolumeEncryption
-		}
-	}
-
-	// Size.
-	{
-		size := fi.ValueOf(ig.Spec.RootVolumeSize)
-		if size == 0 {
-			var err error
-			size, err = defaults.DefaultInstanceGroupVolumeSize(ig.Spec.Role)
-			if err != nil {
-				return nil, err
+	var size int32
+	var typ string
+	var iops int32
+	var throughput int32
+	if ig.Spec.RootVolume != nil {
+		// Optimization.
+		{
+			if fi.ValueOf(ig.Spec.RootVolume.Optimization) {
+				opts.Optimization = ig.Spec.RootVolume.Optimization
 			}
 		}
-		opts.Size = fi.PtrTo(int64(size))
+
+		// Encryption.
+		{
+			if fi.ValueOf(ig.Spec.RootVolume.Encryption) {
+				opts.Encryption = ig.Spec.RootVolume.Encryption
+			}
+		}
+
+		size = fi.ValueOf(ig.Spec.RootVolume.Size)
+		typ = fi.ValueOf(ig.Spec.RootVolume.Type)
+		iops = fi.ValueOf(ig.Spec.RootVolume.IOPS)
+		throughput = fi.ValueOf(ig.Spec.RootVolume.Throughput)
 	}
 
-	// Type.
-	{
-		typ := fi.ValueOf(ig.Spec.RootVolumeType)
-		if typ == "" {
-			typ = "gp2"
-		}
-		opts.Type = fi.PtrTo(typ)
-	}
-
-	// IOPS.
-	{
-		iops := fi.ValueOf(ig.Spec.RootVolumeIOPS)
-		if iops > 0 {
-			opts.IOPS = fi.PtrTo(int64(iops))
+	if size == 0 {
+		var err error
+		size, err = defaults.DefaultInstanceGroupVolumeSize(ig.Spec.Role)
+		if err != nil {
+			return nil, err
 		}
 	}
+	opts.Size = fi.PtrTo(int64(size))
 
-	// Throughput.
-	{
-		throughput := fi.ValueOf(ig.Spec.RootVolumeThroughput)
-		if throughput > 0 {
-			opts.Throughput = fi.PtrTo(int64(throughput))
-		}
+	if typ == "" {
+		typ = "gp2"
+	}
+	opts.Type = fi.PtrTo(typ)
+
+	if iops > 0 {
+		opts.IOPS = fi.PtrTo(int64(iops))
+	}
+
+	if throughput > 0 {
+		opts.Throughput = fi.PtrTo(int64(throughput))
 	}
 
 	return opts, nil
@@ -1036,6 +1055,16 @@ func (b *SpotInstanceGroupModelBuilder) buildAutoScalerOpts(clusterID string, ig
 	return opts, nil
 }
 
+func (b *SpotInstanceGroupModelBuilder) buildInstanceMetadataOptions(ig *kops.InstanceGroup) *spotinsttasks.InstanceMetadataOptions {
+	if ig.Spec.InstanceMetadata != nil {
+		opt := new(spotinsttasks.InstanceMetadataOptions)
+		opt.HTTPPutResponseHopLimit = fi.PtrTo(fi.ValueOf(ig.Spec.InstanceMetadata.HTTPPutResponseHopLimit))
+		opt.HTTPTokens = fi.PtrTo(fi.ValueOf(ig.Spec.InstanceMetadata.HTTPTokens))
+		return opt
+	}
+	return nil
+}
+
 func parseBool(str string) (*bool, error) {
 	v, err := strconv.ParseBool(str)
 	if err != nil {
