@@ -27,17 +27,14 @@ import (
 	"strings"
 
 	"k8s.io/klog/v2"
-	"k8s.io/kops/pkg/apis/kops/model"
-	"k8s.io/kops/upup/pkg/fi/cloudup/scaleway"
-	"k8s.io/kops/upup/pkg/fi/utils"
-	"sigs.k8s.io/yaml"
-
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/nodeup"
 	"k8s.io/kops/pkg/model/resources"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
+	"k8s.io/kops/upup/pkg/fi/cloudup/scaleway"
 	"k8s.io/kops/upup/pkg/fi/fitasks"
+	"k8s.io/kops/upup/pkg/fi/utils"
 	"k8s.io/kops/util/pkg/architectures"
 	"k8s.io/kops/util/pkg/mirrors"
 )
@@ -134,12 +131,7 @@ func (b *BootstrapScript) buildEnvironmentVariables() (map[string]string, error)
 	}
 
 	if os.Getenv("S3_ENDPOINT") != "" {
-		passEnvs := false
-		if b.ig.IsControlPlane() || !b.builder.UseKopsControllerForNodeBootstrap() {
-			passEnvs = true
-		}
-
-		if passEnvs {
+		if b.ig.IsControlPlane() {
 			env["S3_ENDPOINT"] = os.Getenv("S3_ENDPOINT")
 			env["S3_REGION"] = os.Getenv("S3_REGION")
 			env["S3_ACCESS_KEY_ID"] = os.Getenv("S3_ACCESS_KEY_ID")
@@ -157,13 +149,8 @@ func (b *BootstrapScript) buildEnvironmentVariables() (map[string]string, error)
 			"OS_REGION_NAME",
 		}
 
-		hasCCM := cluster.Spec.ExternalCloudControllerManager != nil
 		appCreds := os.Getenv("OS_APPLICATION_CREDENTIAL_ID") != "" && os.Getenv("OS_APPLICATION_CREDENTIAL_SECRET") != ""
-		if !hasCCM && appCreds {
-			klog.Warning("application credentials only supported when using external cloud controller manager. Continuing with passwords.")
-		}
-
-		if hasCCM && appCreds {
+		if appCreds {
 			osEnvs = append(osEnvs,
 				"OS_APPLICATION_CREDENTIAL_ID",
 				"OS_APPLICATION_CREDENTIAL_SECRET",
@@ -190,12 +177,7 @@ func (b *BootstrapScript) buildEnvironmentVariables() (map[string]string, error)
 	}
 
 	if cluster.Spec.GetCloudProvider() == kops.CloudProviderDO {
-		passEnvs := false
-		if b.ig.IsControlPlane() || !b.builder.UseKopsControllerForNodeBootstrap() {
-			passEnvs = true
-		}
-
-		if passEnvs {
+		if b.ig.IsControlPlane() {
 			doToken := os.Getenv("DIGITALOCEAN_ACCESS_TOKEN")
 			if doToken != "" {
 				env["DIGITALOCEAN_ACCESS_TOKEN"] = doToken
@@ -255,16 +237,8 @@ func (b *BootstrapScriptBuilder) ResourceNodeUp(c *fi.CloudupModelBuilderContext
 		}
 	}
 
-	if model.UseCiliumEtcd(b.Cluster) && !model.UseKopsControllerForNodeBootstrap(b.Cluster) {
-		keypairs = append(keypairs, "etcd-client-cilium")
-	}
 	if ig.HasAPIServer() {
 		keypairs = append(keypairs, "apiserver-aggregator-ca", "service-account", "etcd-clients-ca")
-	} else if !model.UseKopsControllerForNodeBootstrap(b.Cluster) {
-		keypairs = append(keypairs, "kubelet", "kube-proxy")
-		if b.Cluster.Spec.Networking.KubeRouter != nil {
-			keypairs = append(keypairs, "kube-router")
-		}
 	}
 
 	if ig.IsBastion() {
@@ -365,55 +339,6 @@ func (b *BootstrapScript) Run(c *fi.CloudupContext) error {
 		nodeupScript.ProxyEnv = func() (string, error) {
 			return b.createProxyEnv(c.T.Cluster.Spec.Networking.EgressProxy)
 		}
-
-		nodeupScript.ClusterSpec = func() (string, error) {
-			cs := c.T.Cluster.Spec
-
-			spec := make(map[string]interface{})
-			spec["cloudConfig"] = cs.CloudConfig
-			spec["kubelet"] = cs.Kubelet
-
-			if cs.KubeAPIServer != nil && cs.KubeAPIServer.EnableBootstrapAuthToken != nil {
-				spec["kubeAPIServer"] = map[string]interface{}{
-					"enableBootstrapAuthToken": cs.KubeAPIServer.EnableBootstrapAuthToken,
-				}
-			}
-
-			if b.ig.IsControlPlane() {
-				spec["encryptionConfig"] = cs.EncryptionConfig
-				spec["etcdClusters"] = make(map[string]kops.EtcdClusterSpec)
-				spec["kubeAPIServer"] = cs.KubeAPIServer
-				spec["kubeControllerManager"] = cs.KubeControllerManager
-				spec["kubeScheduler"] = cs.KubeScheduler
-				spec["masterKubelet"] = cs.ControlPlaneKubelet
-
-				for _, etcdCluster := range cs.EtcdClusters {
-					c := kops.EtcdClusterSpec{
-						Image:         etcdCluster.Image,
-						Version:       etcdCluster.Version,
-						Manager:       etcdCluster.Manager,
-						CPURequest:    etcdCluster.CPURequest,
-						MemoryRequest: etcdCluster.MemoryRequest,
-					}
-					for _, etcdMember := range etcdCluster.Members {
-						if fi.ValueOf(etcdMember.InstanceGroup) == b.ig.Name && etcdMember.VolumeSize != nil {
-							m := kops.EtcdMemberSpec{
-								Name:       etcdMember.Name,
-								VolumeSize: etcdMember.VolumeSize,
-							}
-							c.Members = append(c.Members, m)
-						}
-					}
-					spec["etcdClusters"].(map[string]kops.EtcdClusterSpec)[etcdCluster.Name] = c
-				}
-			}
-
-			content, err := yaml.Marshal(spec)
-			if err != nil {
-				return "", fmt.Errorf("error converting cluster spec to yaml for inclusion within bootstrap script: %v", err)
-			}
-			return string(content), nil
-		}
 	}
 
 	nodeupScript.CompressUserData = fi.ValueOf(b.ig.Spec.CompressUserData)
