@@ -55,22 +55,16 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 
 	eccm.ClusterName = b.ClusterName
 
-	eccm.ClusterCIDR = clusterSpec.Networking.NonMasqueradeCIDR
+	eccm.AllocateNodeCIDRs = fi.PtrTo(!clusterSpec.IsKopsControllerIPAM())
 
-	eccm.AllocateNodeCIDRs = fi.PtrTo(true)
-	eccm.ConfigureCloudRoutes = fi.PtrTo(false)
+	if eccm.ClusterCIDR == "" && !clusterSpec.IsKopsControllerIPAM() {
+		eccm.ClusterCIDR = clusterSpec.Networking.PodCIDR
+	}
 
 	// TODO: we want to consolidate this with the logic from KCM
 	networking := &clusterSpec.Networking
 	if networking.Kubenet != nil {
 		eccm.ConfigureCloudRoutes = fi.PtrTo(true)
-	} else if networking.GCE != nil {
-		eccm.ConfigureCloudRoutes = fi.PtrTo(false)
-		eccm.CIDRAllocatorType = fi.PtrTo("CloudAllocator")
-
-		if eccm.ClusterCIDR == "" {
-			eccm.ClusterCIDR = clusterSpec.Networking.PodCIDR
-		}
 	} else if networking.External != nil {
 		eccm.ConfigureCloudRoutes = fi.PtrTo(false)
 	} else if UsesCNI(networking) {
@@ -85,18 +79,20 @@ func (b *AWSCloudControllerManagerOptionsBuilder) BuildOptions(o interface{}) er
 	if eccm.Image == "" {
 		// See https://us.gcr.io/k8s-artifacts-prod/provider-aws/cloud-controller-manager
 		switch b.KubernetesVersion.Minor {
-		case 22:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.22.7"
 		case 23:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.23.6"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.23.17"
 		case 24:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.3"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.24.15"
 		case 25:
 			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.25.3"
 		case 26:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.26.0"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.26.6"
+		case 27:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.27.2"
+		case 28:
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.28.1"
 		default:
-			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.26.0"
+			eccm.Image = "registry.k8s.io/provider-aws/cloud-controller-manager:v1.28.1"
 		}
 	}
 
