@@ -37,20 +37,12 @@ func (b *DefaultsOptionsBuilder) BuildOptions(o interface{}) error {
 	}
 
 	if options.ContainerRuntime == "" {
-		if b.Context.IsKubernetesLT("1.20") || options.Docker != nil {
+		if options.Docker != nil {
 			options.ContainerRuntime = "docker"
 		} else {
 			options.ContainerRuntime = "containerd"
 		}
 	}
 
-	if options.ExternalDNS == nil {
-		options.ExternalDNS = &kops.ExternalDNSConfig{}
-	}
-
-	if options.ExternalDNS.Provider == "" {
-		options.ExternalDNS.Provider = kops.ExternalDNSProviderDNSController
-	}
-
 	return nil
 }
