@@ -174,7 +174,9 @@ func TestPolicyGeneration(t *testing.T) {
 		b := &PolicyBuilder{
 			Cluster: &kops.Cluster{
 				Spec: kops.ClusterSpec{
-					ConfigStore: "s3://kops-tests/iam-builder-test.k8s.local",
+					ConfigStore: kops.ConfigStoreSpec{
+						Base: "s3://kops-tests/iam-builder-test.k8s.local",
+					},
 					IAM: &kops.IAMSpec{
 						AllowContainerRegistry: x.AllowContainerRegistry,
 					},
