@@ -299,7 +299,7 @@ func (d *clusterDiscoveryGCE) listManagedInstances(igm *compute.InstanceGroupMan
 func (d *clusterDiscoveryGCE) findGCEDisks() ([]*compute.Disk, error) {
 	c := d.gceCloud
 
-	clusterTag := gce.SafeClusterName(d.clusterName)
+	clusterLabel := gce.LabelForCluster(d.clusterName)
 
 	var matches []*compute.Disk
 
@@ -316,8 +316,8 @@ func (d *clusterDiscoveryGCE) findGCEDisks() ([]*compute.Disk, error) {
 		for _, d := range list.Disks {
 			match := false
 			for k, v := range d.Labels {
-				if k == gce.GceLabelNameKubernetesCluster {
-					if v == clusterTag {
+				if k == clusterLabel.Key {
+					if v == clusterLabel.Value {
 						match = true
 					} else {
 						match = false
@@ -753,6 +753,9 @@ func (d *clusterDiscoveryGCE) listRoutes(ctx context.Context, resourceMap map[st
 			switch w.Code {
 			case "NEXT_HOP_INSTANCE_NOT_FOUND":
 				remove = true
+			case "NEXT_HOP_NOT_RUNNING":
+				// It might not be running, but it probably exists.
+				remove = false
 			default:
 				klog.Infof("Unknown warning on route %q: %q", r.Name, w.Code)
 			}
