@@ -27,6 +27,7 @@ import (
 	"k8s.io/kops/pkg/resources/gce"
 	"k8s.io/kops/pkg/resources/hetzner"
 	"k8s.io/kops/pkg/resources/openstack"
+	"k8s.io/kops/pkg/resources/scaleway"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
 	cloudazure "k8s.io/kops/upup/pkg/fi/cloudup/azure"
@@ -34,24 +35,35 @@ import (
 	cloudgce "k8s.io/kops/upup/pkg/fi/cloudup/gce"
 	cloudhetzner "k8s.io/kops/upup/pkg/fi/cloudup/hetzner"
 	cloudopenstack "k8s.io/kops/upup/pkg/fi/cloudup/openstack"
+	cloudscaleway "k8s.io/kops/upup/pkg/fi/cloudup/scaleway"
 )
 
 // ListResources collects the resources from the specified cloud
-func ListResources(cloud fi.Cloud, cluster *kops.Cluster, region string) (map[string]*resources.Resource, error) {
-	clusterName := cluster.Name
+func ListResources(cloud fi.Cloud, cluster *kops.Cluster) (map[string]*resources.Resource, error) {
+	clusterInfo := resources.ClusterInfo{
+		Name:        cluster.Name,
+		UsesNoneDNS: cluster.UsesNoneDNS(),
+	}
+
 	switch cloud.ProviderID() {
 	case kops.CloudProviderAWS:
-		return aws.ListResourcesAWS(cloud.(awsup.AWSCloud), clusterName)
+		return aws.ListResourcesAWS(cloud.(awsup.AWSCloud), clusterInfo)
 	case kops.CloudProviderDO:
-		return digitalocean.ListResources(cloud.(clouddo.DOCloud), clusterName)
+		return digitalocean.ListResources(cloud.(clouddo.DOCloud), clusterInfo)
 	case kops.CloudProviderGCE:
-		return gce.ListResourcesGCE(cloud.(cloudgce.GCECloud), clusterName, region)
+		return gce.ListResourcesGCE(cloud.(cloudgce.GCECloud), clusterInfo)
 	case kops.CloudProviderHetzner:
-		return hetzner.ListResources(cloud.(cloudhetzner.HetznerCloud), clusterName)
+		return hetzner.ListResources(cloud.(cloudhetzner.HetznerCloud), clusterInfo)
 	case kops.CloudProviderOpenstack:
-		return openstack.ListResources(cloud.(cloudopenstack.OpenstackCloud), clusterName)
+		return openstack.ListResources(cloud.(cloudopenstack.OpenstackCloud), clusterInfo)
 	case kops.CloudProviderAzure:
-		return azure.ListResourcesAzure(cloud.(cloudazure.AzureCloud), cluster)
+		clusterInfo.AzureResourceGroupName = cluster.AzureResourceGroupName()
+		clusterInfo.AzureResourceGroupShared = cluster.IsSharedAzureResourceGroup()
+		clusterInfo.AzureNetworkShared = cluster.SharedVPC()
+		clusterInfo.AzureRouteTableShared = cluster.IsSharedAzureRouteTable()
+		return azure.ListResourcesAzure(cloud.(cloudazure.AzureCloud), clusterInfo)
+	case kops.CloudProviderScaleway:
+		return scaleway.ListResources(cloud.(cloudscaleway.ScwCloud), clusterInfo)
 	default:
 		return nil, fmt.Errorf("delete on clusters on %q not (yet) supported", cloud.ProviderID())
 	}
