@@ -19,8 +19,9 @@ source "${REPO_ROOT}"/tests/e2e/scenarios/lib/common.sh
 
 kops-acquire-latest
 
-OVERRIDES="${OVERRIDES-} --override=cluster.spec.metricsServer.enabled=true"
-OVERRIDES="$OVERRIDES --override=cluster.spec.certManager.enabled=true"
+OVERRIDES="${OVERRIDES-} --set=cluster.spec.metricsServer.enabled=true"
+OVERRIDES="$OVERRIDES --set=cluster.spec.certManager.enabled=true"
+OVERRIDES="${OVERRIDES} --master-size=t4g.medium --node-size=t4g.medium"
 
 kops-up
 
