@@ -29,7 +29,6 @@ import (
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 	"k8s.io/kops/util/pkg/slice"
@@ -76,6 +75,7 @@ type ClassicLoadBalancer struct {
 }
 
 var _ fi.CompareWithID = &ClassicLoadBalancer{}
+var _ fi.CloudupTaskNormalize = &ClassicLoadBalancer{}
 
 func (e *ClassicLoadBalancer) CompareWithID() *string {
 	return e.Name
@@ -104,9 +104,9 @@ func (e *ClassicLoadBalancerListener) mapToAWS(loadBalancerPort int64) *elb.List
 	return l
 }
 
-var _ fi.HasDependencies = &ClassicLoadBalancerListener{}
+var _ fi.CloudupHasDependencies = &ClassicLoadBalancerListener{}
 
-func (e *ClassicLoadBalancerListener) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (e *ClassicLoadBalancerListener) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
@@ -209,10 +209,10 @@ func (e *ClassicLoadBalancer) getHostedZoneId() *string {
 	return e.HostedZoneId
 }
 
-func (e *ClassicLoadBalancer) Find(c *fi.Context) (*ClassicLoadBalancer, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *ClassicLoadBalancer) Find(c *fi.CloudupContext) (*ClassicLoadBalancer, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
-	lb, err := cloud.FindELBByNameTag(fi.StringValue(e.Name))
+	lb, err := cloud.FindELBByNameTag(fi.ValueOf(e.Name))
 	if err != nil {
 		return nil, err
 	}
@@ -327,13 +327,12 @@ func (e *ClassicLoadBalancer) Find(c *fi.Context) (*ClassicLoadBalancer, error)
 	// We allow for the LoadBalancerName to be wrong:
 	// 1. We don't want to force a rename of the ELB, because that is a destructive operation
 	// 2. We were creating ELBs with insufficiently qualified names previously
-	if fi.StringValue(e.LoadBalancerName) != fi.StringValue(actual.LoadBalancerName) {
+	if fi.ValueOf(e.LoadBalancerName) != fi.ValueOf(actual.LoadBalancerName) {
 		klog.V(2).Infof("Reusing existing load balancer with name: %q", aws.StringValue(actual.LoadBalancerName))
 		e.LoadBalancerName = actual.LoadBalancerName
 	}
 
-	// TODO: Make Normalize a standard method
-	actual.Normalize()
+	_ = actual.Normalize(c)
 
 	klog.V(4).Infof("Found ELB %+v", actual)
 
@@ -346,10 +345,10 @@ func (e *ClassicLoadBalancer) IsForAPIServer() bool {
 	return e.ForAPIServer
 }
 
-func (e *ClassicLoadBalancer) FindAddresses(context *fi.Context) ([]string, error) {
-	cloud := context.Cloud.(awsup.AWSCloud)
+func (e *ClassicLoadBalancer) FindAddresses(context *fi.CloudupContext) ([]string, error) {
+	cloud := context.T.Cloud.(awsup.AWSCloud)
 
-	lb, err := cloud.FindELBByNameTag(fi.StringValue(e.Name))
+	lb, err := cloud.FindELBByNameTag(fi.ValueOf(e.Name))
 	if err != nil {
 		return nil, err
 	}
@@ -357,40 +356,38 @@ func (e *ClassicLoadBalancer) FindAddresses(context *fi.Context) ([]string, erro
 		return nil, nil
 	}
 
-	lbDnsName := fi.StringValue(lb.DNSName)
+	lbDnsName := fi.ValueOf(lb.DNSName)
 	if lbDnsName == "" {
 		return nil, nil
 	}
 	return []string{lbDnsName}, nil
 }
 
-func (e *ClassicLoadBalancer) Run(c *fi.Context) error {
-	// TODO: Make Normalize a standard method
-	e.Normalize()
-
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *ClassicLoadBalancer) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *ClassicLoadBalancer) ShouldCreate(a, e, changes *ClassicLoadBalancer) (bool, error) {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		return false, nil
 	}
 	return true, nil
 }
 
-func (e *ClassicLoadBalancer) Normalize() {
+func (e *ClassicLoadBalancer) Normalize(c *fi.CloudupContext) error {
 	// We need to sort our arrays consistently, so we don't get spurious changes
 	sort.Stable(OrderSubnetsById(e.Subnets))
 	sort.Stable(OrderSecurityGroupsById(e.SecurityGroups))
+	return nil
 }
 
 func (s *ClassicLoadBalancer) CheckChanges(a, e, changes *ClassicLoadBalancer) error {
 	if a == nil {
-		if fi.StringValue(e.Name) == "" {
+		if fi.ValueOf(e.Name) == "" {
 			return fi.RequiredField("Name")
 		}
 
-		shared := fi.BoolValue(e.Shared)
+		shared := fi.ValueOf(e.Shared)
 		if !shared {
 			if len(e.SecurityGroups) == 0 {
 				return fi.RequiredField("SecurityGroups")
@@ -427,7 +424,7 @@ func (s *ClassicLoadBalancer) CheckChanges(a, e, changes *ClassicLoadBalancer) e
 }
 
 func (_ *ClassicLoadBalancer) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *ClassicLoadBalancer) error {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		return nil
 	}
@@ -482,17 +479,17 @@ func (_ *ClassicLoadBalancer) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Cl
 		}
 		e.HostedZoneId = lb.CanonicalHostedZoneNameID
 	} else {
-		loadBalancerName = fi.StringValue(a.LoadBalancerName)
+		loadBalancerName = fi.ValueOf(a.LoadBalancerName)
 
 		if changes.Subnets != nil {
 			var expectedSubnets []string
 			for _, s := range e.Subnets {
-				expectedSubnets = append(expectedSubnets, fi.StringValue(s.ID))
+				expectedSubnets = append(expectedSubnets, fi.ValueOf(s.ID))
 			}
 
 			var actualSubnets []string
 			for _, s := range a.Subnets {
-				actualSubnets = append(actualSubnets, fi.StringValue(s.ID))
+				actualSubnets = append(actualSubnets, fi.ValueOf(s.ID))
 			}
 
 			oldSubnetIDs := slice.GetUniqueStrings(expectedSubnets, actualSubnets)
@@ -610,7 +607,7 @@ type OrderLoadBalancersByName []*ClassicLoadBalancer
 func (a OrderLoadBalancersByName) Len() int      { return len(a) }
 func (a OrderLoadBalancersByName) Swap(i, j int) { a[i], a[j] = a[j], a[i] }
 func (a OrderLoadBalancersByName) Less(i, j int) bool {
-	return fi.StringValue(a[i].Name) < fi.StringValue(a[j].Name)
+	return fi.ValueOf(a[i].Name) < fi.ValueOf(a[j].Name)
 }
 
 type terraformLoadBalancer struct {
@@ -650,7 +647,7 @@ type terraformLoadBalancerHealthCheck struct {
 }
 
 func (_ *ClassicLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *ClassicLoadBalancer) error {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		return nil
 	}
@@ -664,8 +661,8 @@ func (_ *ClassicLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e
 	tf := &terraformLoadBalancer{
 		LoadBalancerName: e.LoadBalancerName,
 	}
-	if fi.StringValue(e.Scheme) == "internal" {
-		tf.Internal = fi.Bool(true)
+	if fi.ValueOf(e.Scheme) == "internal" {
+		tf.Internal = fi.PtrTo(true)
 	}
 
 	for _, subnet := range e.Subnets {
@@ -713,7 +710,7 @@ func (_ *ClassicLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e
 		}
 	}
 
-	if e.AccessLog != nil && fi.BoolValue(e.AccessLog.Enabled) {
+	if e.AccessLog != nil && fi.ValueOf(e.AccessLog.Enabled) {
 		tf.AccessLog = &terraformLoadBalancerAccessLog{
 			EmitInterval:   e.AccessLog.EmitInterval,
 			Enabled:        e.AccessLog.Enabled,
@@ -745,7 +742,7 @@ func (_ *ClassicLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e
 }
 
 func (e *ClassicLoadBalancer) TerraformLink(params ...string) *terraformWriter.Literal {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		if e.LoadBalancerName == nil {
 			klog.Fatalf("Name must be set, if LB is shared: %s", e)
@@ -761,151 +758,3 @@ func (e *ClassicLoadBalancer) TerraformLink(params ...string) *terraformWriter.L
 	}
 	return terraformWriter.LiteralProperty("aws_elb", *e.Name, prop)
 }
-
-type cloudformationClassicLoadBalancer struct {
-	LoadBalancerName *string                                      `json:"LoadBalancerName,omitempty"`
-	Listener         []*cloudformationClassicLoadBalancerListener `json:"Listeners,omitempty"`
-	SecurityGroups   []*cloudformation.Literal                    `json:"SecurityGroups,omitempty"`
-	Subnets          []*cloudformation.Literal                    `json:"Subnets,omitempty"`
-	Scheme           *string                                      `json:"Scheme,omitempty"`
-
-	HealthCheck *cloudformationClassicLoadBalancerHealthCheck `json:"HealthCheck,omitempty"`
-	AccessLog   *cloudformationClassicLoadBalancerAccessLog   `json:"AccessLoggingPolicy,omitempty"`
-
-	ConnectionDrainingPolicy *cloudformationConnectionDrainingPolicy `json:"ConnectionDrainingPolicy,omitempty"`
-	ConnectionSettings       *cloudformationConnectionSettings       `json:"ConnectionSettings,omitempty"`
-
-	CrossZoneLoadBalancing *bool `json:"CrossZone,omitempty"`
-
-	Tags []cloudformationTag `json:"Tags,omitempty"`
-}
-
-type cloudformationClassicLoadBalancerListener struct {
-	InstancePort         string `json:"InstancePort"`
-	InstanceProtocol     string `json:"InstanceProtocol"`
-	LoadBalancerPort     string `json:"LoadBalancerPort"`
-	LoadBalancerProtocol string `json:"Protocol"`
-}
-
-type cloudformationClassicLoadBalancerHealthCheck struct {
-	Target             *string `json:"Target"`
-	HealthyThreshold   *string `json:"HealthyThreshold"`
-	UnhealthyThreshold *string `json:"UnhealthyThreshold"`
-	Interval           *string `json:"Interval"`
-	Timeout            *string `json:"Timeout"`
-}
-
-type cloudformationConnectionDrainingPolicy struct {
-	Enabled *bool  `json:"Enabled,omitempty"`
-	Timeout *int64 `json:"Timeout,omitempty"`
-}
-
-type cloudformationConnectionSettings struct {
-	IdleTimeout *int64 `json:"IdleTimeout,omitempty"`
-}
-
-func (_ *ClassicLoadBalancer) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *ClassicLoadBalancer) error {
-	// TODO: From http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-elb.html:
-	// If this resource has a public IP address and is also in a VPC that is defined in the same template,
-	// you must use the DependsOn attribute to declare a dependency on the VPC-gateway attachment.
-
-	shared := fi.BoolValue(e.Shared)
-	if shared {
-		return nil
-	}
-
-	cloud := t.Cloud.(awsup.AWSCloud)
-
-	if e.LoadBalancerName == nil {
-		return fi.RequiredField("LoadBalancerName")
-	}
-
-	tf := &cloudformationClassicLoadBalancer{
-		LoadBalancerName: e.LoadBalancerName,
-		Scheme:           e.Scheme,
-	}
-
-	for _, subnet := range e.Subnets {
-		tf.Subnets = append(tf.Subnets, subnet.CloudformationLink())
-	}
-
-	for _, sg := range e.SecurityGroups {
-		tf.SecurityGroups = append(tf.SecurityGroups, sg.CloudformationLink())
-	}
-
-	for loadBalancerPort, listener := range e.Listeners {
-		tf.Listener = append(tf.Listener, &cloudformationClassicLoadBalancerListener{
-			InstanceProtocol:     "TCP",
-			InstancePort:         strconv.Itoa(listener.InstancePort),
-			LoadBalancerPort:     loadBalancerPort,
-			LoadBalancerProtocol: "TCP",
-		})
-	}
-
-	if e.HealthCheck != nil {
-		tf.HealthCheck = &cloudformationClassicLoadBalancerHealthCheck{
-			Target:             e.HealthCheck.Target,
-			HealthyThreshold:   fi.ToString(e.HealthCheck.HealthyThreshold),
-			UnhealthyThreshold: fi.ToString(e.HealthCheck.UnhealthyThreshold),
-			Interval:           fi.ToString(e.HealthCheck.Interval),
-			Timeout:            fi.ToString(e.HealthCheck.Timeout),
-		}
-	}
-
-	if e.AccessLog != nil && fi.BoolValue(e.AccessLog.Enabled) {
-		tf.AccessLog = &cloudformationClassicLoadBalancerAccessLog{
-			EmitInterval:   e.AccessLog.EmitInterval,
-			Enabled:        e.AccessLog.Enabled,
-			S3BucketName:   e.AccessLog.S3BucketName,
-			S3BucketPrefix: e.AccessLog.S3BucketPrefix,
-		}
-	}
-
-	if e.ConnectionDraining != nil {
-		tf.ConnectionDrainingPolicy = &cloudformationConnectionDrainingPolicy{
-			Enabled: e.ConnectionDraining.Enabled,
-			Timeout: e.ConnectionDraining.Timeout,
-		}
-	}
-
-	if e.ConnectionSettings != nil {
-		tf.ConnectionSettings = &cloudformationConnectionSettings{
-			IdleTimeout: e.ConnectionSettings.IdleTimeout,
-		}
-	}
-
-	if e.CrossZoneLoadBalancing != nil {
-		tf.CrossZoneLoadBalancing = e.CrossZoneLoadBalancing.Enabled
-	}
-
-	tags := cloud.BuildTags(e.Name)
-	for k, v := range e.Tags {
-		tags[k] = v
-	}
-
-	tf.Tags = buildCloudformationTags(tags)
-
-	return t.RenderResource("AWS::ElasticLoadBalancing::LoadBalancer", *e.Name, tf)
-}
-
-func (e *ClassicLoadBalancer) CloudformationLink() *cloudformation.Literal {
-	shared := fi.BoolValue(e.Shared)
-	if shared {
-		if e.LoadBalancerName == nil {
-			klog.Fatalf("Name must be set, if LB is shared: %s", e)
-		}
-
-		klog.V(4).Infof("reusing existing LB with name %q", *e.LoadBalancerName)
-		return cloudformation.LiteralString(*e.LoadBalancerName)
-	}
-
-	return cloudformation.Ref("AWS::ElasticLoadBalancing::LoadBalancer", *e.Name)
-}
-
-func (e *ClassicLoadBalancer) CloudformationAttrCanonicalHostedZoneNameID() *cloudformation.Literal {
-	return cloudformation.GetAtt("AWS::ElasticLoadBalancing::LoadBalancer", *e.Name, "CanonicalHostedZoneNameID")
-}
-
-func (e *ClassicLoadBalancer) CloudformationAttrDNSName() *cloudformation.Literal {
-	return cloudformation.GetAtt("AWS::ElasticLoadBalancing::LoadBalancer", *e.Name, "DNSName")
-}
