@@ -33,7 +33,7 @@ type ClassicLoadBalancerAccessLog struct {
 	S3BucketPrefix *string
 }
 
-func (_ *ClassicLoadBalancerAccessLog) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (_ *ClassicLoadBalancerAccessLog) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
@@ -44,13 +44,6 @@ type terraformLoadBalancerAccessLog struct {
 	S3BucketPrefix *string `cty:"bucket_prefix"`
 }
 
-type cloudformationClassicLoadBalancerAccessLog struct {
-	EmitInterval   *int64  `json:"EmitInterval,omitempty"`
-	Enabled        *bool   `json:"Enabled,omitempty"`
-	S3BucketName   *string `json:"S3BucketName,omitempty"`
-	S3BucketPrefix *string `json:"S3BucketPrefix,omitempty"`
-}
-
 //type LoadBalancerAdditionalAttribute struct {
 //	Key   *string
 //	Value *string
@@ -65,7 +58,7 @@ type ClassicLoadBalancerConnectionDraining struct {
 	Timeout *int64
 }
 
-func (_ *ClassicLoadBalancerConnectionDraining) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (_ *ClassicLoadBalancerConnectionDraining) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
@@ -73,7 +66,7 @@ type ClassicLoadBalancerCrossZoneLoadBalancing struct {
 	Enabled *bool
 }
 
-func (_ *ClassicLoadBalancerCrossZoneLoadBalancing) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (_ *ClassicLoadBalancerCrossZoneLoadBalancing) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
@@ -81,7 +74,7 @@ type ClassicLoadBalancerConnectionSettings struct {
 	IdleTimeout *int64
 }
 
-func (_ *ClassicLoadBalancerConnectionSettings) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (_ *ClassicLoadBalancerConnectionSettings) GetDependencies(tasks map[string]fi.CloudupTask) []fi.CloudupTask {
 	return nil
 }
 
@@ -110,7 +103,7 @@ func (_ *ClassicLoadBalancer) modifyLoadBalancerAttributes(t *awsup.AWSAPITarget
 		return nil
 	}
 
-	loadBalancerName := fi.StringValue(e.LoadBalancerName)
+	loadBalancerName := fi.ValueOf(e.LoadBalancerName)
 
 	request := &elb.ModifyLoadBalancerAttributesInput{}
 	request.LoadBalancerName = e.LoadBalancerName
@@ -119,22 +112,22 @@ func (_ *ClassicLoadBalancer) modifyLoadBalancerAttributes(t *awsup.AWSAPITarget
 	// Setting mandatory attributes to default values if empty
 	request.LoadBalancerAttributes.AccessLog = &elb.AccessLog{}
 	if e.AccessLog == nil || e.AccessLog.Enabled == nil {
-		request.LoadBalancerAttributes.AccessLog.Enabled = fi.Bool(false)
+		request.LoadBalancerAttributes.AccessLog.Enabled = fi.PtrTo(false)
 	}
 	request.LoadBalancerAttributes.ConnectionDraining = &elb.ConnectionDraining{}
 	if e.ConnectionDraining == nil || e.ConnectionDraining.Enabled == nil {
-		request.LoadBalancerAttributes.ConnectionDraining.Enabled = fi.Bool(false)
+		request.LoadBalancerAttributes.ConnectionDraining.Enabled = fi.PtrTo(false)
 	}
 	if e.ConnectionDraining == nil || e.ConnectionDraining.Timeout == nil {
-		request.LoadBalancerAttributes.ConnectionDraining.Timeout = fi.Int64(300)
+		request.LoadBalancerAttributes.ConnectionDraining.Timeout = fi.PtrTo(int64(300))
 	}
 	request.LoadBalancerAttributes.ConnectionSettings = &elb.ConnectionSettings{}
 	if e.ConnectionSettings == nil || e.ConnectionSettings.IdleTimeout == nil {
-		request.LoadBalancerAttributes.ConnectionSettings.IdleTimeout = fi.Int64(60)
+		request.LoadBalancerAttributes.ConnectionSettings.IdleTimeout = fi.PtrTo(int64(60))
 	}
 	request.LoadBalancerAttributes.CrossZoneLoadBalancing = &elb.CrossZoneLoadBalancing{}
 	if e.CrossZoneLoadBalancing == nil || e.CrossZoneLoadBalancing.Enabled == nil {
-		request.LoadBalancerAttributes.CrossZoneLoadBalancing.Enabled = fi.Bool(false)
+		request.LoadBalancerAttributes.CrossZoneLoadBalancing.Enabled = fi.PtrTo(false)
 	} else {
 		request.LoadBalancerAttributes.CrossZoneLoadBalancing.Enabled = e.CrossZoneLoadBalancing.Enabled
 	}
