@@ -26,7 +26,6 @@ import (
 
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 )
 
@@ -60,8 +59,8 @@ func (e *ElasticIP) CompareWithID() *string {
 }
 
 // Find returns the actual ElasticIP state, or nil if not found
-func (e *ElasticIP) Find(context *fi.Context) (*ElasticIP, error) {
-	return e.find(context.Cloud.(awsup.AWSCloud))
+func (e *ElasticIP) Find(context *fi.CloudupContext) (*ElasticIP, error) {
+	return e.find(context.T.Cloud.(awsup.AWSCloud))
 }
 
 // find will attempt to look up the elastic IP from AWS
@@ -190,8 +189,8 @@ func (e *ElasticIP) find(cloud awsup.AWSCloud) (*ElasticIP, error) {
 // This is the main entry point of the task, and will actually
 // connect our internal resource representation to an actual
 // resource in AWS
-func (e *ElasticIP) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *ElasticIP) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 // CheckChanges validates the resource. EIPs are simple, so virtually no
@@ -265,7 +264,7 @@ func (_ *ElasticIP) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *ElasticIP) e
 	} else {
 		// TODO: Figure out what we can do.  We're sort of stuck between wanting to have one code-path with
 		// terraform, and having a bigger "window of loss" here before we create the NATGateway
-		klog.V(2).Infof("ElasticIP %q not tagged on subnet; risk of leaking", fi.StringValue(publicIp))
+		klog.V(2).Infof("ElasticIP %q not tagged on subnet; risk of leaking", fi.ValueOf(publicIp))
 	}
 
 	return nil
@@ -277,7 +276,7 @@ type terraformElasticIP struct {
 }
 
 func (_ *ElasticIP) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *ElasticIP) error {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		if e.ID == nil {
 			return fmt.Errorf("ID must be set, if ElasticIP is shared: %v", e)
 		}
@@ -294,7 +293,7 @@ func (_ *ElasticIP) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 }
 
 func (e *ElasticIP) TerraformLink() *terraformWriter.Literal {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		if e.ID == nil {
 			klog.Fatalf("ID must be set, if ElasticIP is shared: %v", e)
 		}
@@ -303,41 +302,3 @@ func (e *ElasticIP) TerraformLink() *terraformWriter.Literal {
 
 	return terraformWriter.LiteralProperty("aws_eip", *e.Name, "id")
 }
-
-type cloudformationElasticIP struct {
-	Domain *string             `json:"Domain"`
-	Tags   []cloudformationTag `json:"Tags,omitempty"`
-}
-
-func (_ *ElasticIP) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *ElasticIP) error {
-	if fi.BoolValue(e.Shared) {
-		if e.ID == nil {
-			return fmt.Errorf("ID must be set, if ElasticIP is shared: %v", e)
-		}
-		klog.V(4).Infof("reusing existing ElasticIP with id %q", aws.StringValue(e.ID))
-		return nil
-	}
-
-	tf := &cloudformationElasticIP{
-		Domain: aws.String("vpc"),
-		Tags:   buildCloudformationTags(e.Tags),
-	}
-
-	return t.RenderResource("AWS::EC2::EIP", *e.Name, tf)
-}
-
-// Removed because you normally want CloudformationAllocationID
-//func (e *ElasticIP) CloudformationLink() *cloudformation.Literal {
-//	return cloudformation.Ref("AWS::EC2::EIP", *e.Name)
-//}
-
-func (e *ElasticIP) CloudformationAllocationID() *cloudformation.Literal {
-	if fi.BoolValue(e.Shared) {
-		if e.ID == nil {
-			klog.Fatalf("ID must be set, if ElasticIP is shared: %v", e)
-		}
-		return cloudformation.LiteralString(*e.ID)
-	}
-
-	return cloudformation.GetAtt("AWS::EC2::EIP", *e.Name, "AllocationId")
-}
