@@ -29,7 +29,6 @@ import (
 	"k8s.io/kops/pkg/diff"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -61,8 +60,8 @@ func (e *IAMRole) CompareWithID() *string {
 	return e.ID
 }
 
-func (e *IAMRole) Find(c *fi.Context) (*IAMRole, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *IAMRole) Find(c *fi.CloudupContext) (*IAMRole, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	request := &iam.GetRoleInput{RoleName: e.Name}
 
@@ -129,8 +128,8 @@ func (e *IAMRole) Find(c *fi.Context) (*IAMRole, error) {
 	return actual, nil
 }
 
-func (e *IAMRole) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *IAMRole) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *IAMRole) ShouldCreate(a, e, changes *IAMRole) (bool, error) {
@@ -360,7 +359,7 @@ func (_ *IAMRole) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *I
 		tf.PermissionsBoundary = e.PermissionsBoundary
 	}
 
-	if fi.StringValue(e.ExportWithID) != "" {
+	if fi.ValueOf(e.ExportWithID) != "" {
 		t.AddOutputVariable(*e.ExportWithID+"_role_arn", terraformWriter.LiteralProperty("aws_iam_role", *e.Name, "arn"))
 		t.AddOutputVariable(*e.ExportWithID+"_role_name", e.TerraformLink())
 	}
@@ -371,39 +370,3 @@ func (_ *IAMRole) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *I
 func (e *IAMRole) TerraformLink() *terraformWriter.Literal {
 	return terraformWriter.LiteralProperty("aws_iam_role", *e.Name, "name")
 }
-
-type cloudformationIAMRole struct {
-	RoleName                 *string `json:"RoleName"`
-	AssumeRolePolicyDocument map[string]interface{}
-	PermissionsBoundary      *string             `json:"PermissionsBoundary,omitempty"`
-	Tags                     []cloudformationTag `json:"Tags,omitempty"`
-}
-
-func (_ *IAMRole) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *IAMRole) error {
-	jsonString, err := fi.ResourceAsBytes(e.RolePolicyDocument)
-	if err != nil {
-		return err
-	}
-
-	data := make(map[string]interface{})
-	err = json.Unmarshal(jsonString, &data)
-	if err != nil {
-		return fmt.Errorf("error parsing RolePolicyDocument: %v", err)
-	}
-
-	cf := &cloudformationIAMRole{
-		RoleName:                 e.Name,
-		AssumeRolePolicyDocument: data,
-		Tags:                     buildCloudformationTags(e.Tags),
-	}
-
-	if e.PermissionsBoundary != nil {
-		cf.PermissionsBoundary = e.PermissionsBoundary
-	}
-
-	return t.RenderResource("AWS::IAM::Role", *e.Name, cf)
-}
-
-func (e *IAMRole) CloudformationLink() *cloudformation.Literal {
-	return cloudformation.Ref("AWS::IAM::Role", *e.Name)
-}
