@@ -33,14 +33,14 @@ import (
 // RenderAWS is responsible for performing creating / updating the launch template
 func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchTemplate) error {
 	// @step: resolve the image id to an AMI for us
-	image, err := c.Cloud.ResolveImage(fi.StringValue(t.ImageID))
+	image, err := c.Cloud.ResolveImage(fi.ValueOf(t.ImageID))
 	if err != nil {
 		return err
 	}
 
 	// @step: lets build the launch template data
 	data := &ec2.RequestLaunchTemplateData{
-		DisableApiTermination: fi.Bool(false),
+		DisableApiTermination: fi.PtrTo(false),
 		EbsOptimized:          t.RootVolumeOptimization,
 		ImageId:               image.ImageId,
 		InstanceType:          t.InstanceType,
@@ -53,7 +53,7 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 			{
 				AssociatePublicIpAddress: t.AssociatePublicIP,
 				DeleteOnTermination:      aws.Bool(true),
-				DeviceIndex:              fi.Int64(0),
+				DeviceIndex:              fi.PtrTo(int64(0)),
 				Ipv6AddressCount:         t.IPv6AddressCount,
 			},
 		},
@@ -64,7 +64,7 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 	if err != nil {
 		return fmt.Errorf("failed to build root device: %w", err)
 	}
-	ephemeralDevices, err := buildEphemeralDevices(c.Cloud, fi.StringValue(t.InstanceType))
+	ephemeralDevices, err := buildEphemeralDevices(c.Cloud, fi.ValueOf(t.InstanceType))
 	if err != nil {
 		return fmt.Errorf("failed to build ephemeral devices: %w", err)
 	}
@@ -91,7 +91,7 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 		data.Placement = &ec2.LaunchTemplatePlacementRequest{Tenancy: t.Tenancy}
 	}
 	// @step: set the instance monitoring
-	data.Monitoring = &ec2.LaunchTemplatesMonitoringRequest{Enabled: fi.Bool(false)}
+	data.Monitoring = &ec2.LaunchTemplatesMonitoringRequest{Enabled: fi.PtrTo(false)}
 	if t.InstanceMonitoring != nil {
 		data.Monitoring = &ec2.LaunchTemplatesMonitoringRequest{Enabled: t.InstanceMonitoring}
 	}
@@ -128,18 +128,18 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 		data.UserData = aws.String(base64.StdEncoding.EncodeToString(d))
 	}
 	// @step: add market options
-	if fi.StringValue(t.SpotPrice) != "" {
+	if fi.ValueOf(t.SpotPrice) != "" {
 		s := &ec2.LaunchTemplateSpotMarketOptionsRequest{
 			BlockDurationMinutes:         t.SpotDurationInMinutes,
 			InstanceInterruptionBehavior: t.InstanceInterruptionBehavior,
 			MaxPrice:                     t.SpotPrice,
 		}
 		data.InstanceMarketOptions = &ec2.LaunchTemplateInstanceMarketOptionsRequest{
-			MarketType:  fi.String("spot"),
+			MarketType:  fi.PtrTo("spot"),
 			SpotOptions: s,
 		}
 	}
-	if fi.StringValue(t.CPUCredits) != "" {
+	if fi.ValueOf(t.CPUCredits) != "" {
 		data.CreditSpecification = &ec2.CreditSpecificationRequest{
 			CpuCredits: t.CPUCredits,
 		}
@@ -158,7 +158,7 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 		}
 		output, err := c.Cloud.EC2().CreateLaunchTemplate(input)
 		if err != nil || output.LaunchTemplate == nil {
-			return fmt.Errorf("error creating LaunchTemplate %q: %v", fi.StringValue(t.Name), err)
+			return fmt.Errorf("error creating LaunchTemplate %q: %v", fi.ValueOf(t.Name), err)
 		}
 		e.ID = output.LaunchTemplate.LaunchTemplateId
 	} else {
@@ -179,7 +179,7 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 			}
 		}
 		if changes.Tags != nil {
-			err = c.UpdateTags(fi.StringValue(a.ID), e.Tags)
+			err = c.UpdateTags(fi.ValueOf(a.ID), e.Tags)
 			if err != nil {
 				return fmt.Errorf("error updating LaunchTemplate tags: %v", err)
 			}
@@ -192,10 +192,10 @@ func (t *LaunchTemplate) RenderAWS(c *awsup.AWSAPITarget, a, e, changes *LaunchT
 }
 
 // Find is responsible for finding the launch template for us
-func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
-	cloud, ok := c.Cloud.(awsup.AWSCloud)
+func (t *LaunchTemplate) Find(c *fi.CloudupContext) (*LaunchTemplate, error) {
+	cloud, ok := c.T.Cloud.(awsup.AWSCloud)
 	if !ok {
-		return nil, fmt.Errorf("invalid cloud provider: %v, expected: %s", c.Cloud, "awsup.AWSCloud")
+		return nil, fmt.Errorf("invalid cloud provider: %v, expected: %s", c.T.Cloud, "awsup.AWSCloud")
 	}
 
 	// @step: get the latest launch template version
@@ -207,13 +207,13 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 		return nil, nil
 	}
 
-	klog.V(3).Infof("found existing LaunchTemplate: %s", fi.StringValue(lt.LaunchTemplateName))
+	klog.V(3).Infof("found existing LaunchTemplate: %s", fi.ValueOf(lt.LaunchTemplateName))
 
 	actual := &LaunchTemplate{
-		AssociatePublicIP:      fi.Bool(false),
+		AssociatePublicIP:      fi.PtrTo(false),
 		ID:                     lt.LaunchTemplateId,
 		ImageID:                lt.LaunchTemplateData.ImageId,
-		InstanceMonitoring:     fi.Bool(false),
+		InstanceMonitoring:     fi.PtrTo(false),
 		InstanceType:           lt.LaunchTemplateData.InstanceType,
 		Lifecycle:              t.Lifecycle,
 		Name:                   t.Name,
@@ -223,7 +223,7 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 	// @step: check if any of the interfaces are public facing
 	for _, x := range lt.LaunchTemplateData.NetworkInterfaces {
 		if aws.BoolValue(x.AssociatePublicIpAddress) {
-			actual.AssociatePublicIP = fi.Bool(true)
+			actual.AssociatePublicIP = fi.PtrTo(true)
 		}
 		for _, id := range x.Groups {
 			actual.SecurityGroups = append(actual.SecurityGroups, &SecurityGroup{ID: id})
@@ -232,7 +232,7 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 	}
 	// In older Kops versions, security groups were added to LaunchTemplateData.SecurityGroupIds
 	for _, id := range lt.LaunchTemplateData.SecurityGroupIds {
-		actual.SecurityGroups = append(actual.SecurityGroups, &SecurityGroup{ID: fi.String("legacy-" + *id)})
+		actual.SecurityGroups = append(actual.SecurityGroups, &SecurityGroup{ID: fi.PtrTo("legacy-" + *id)})
 	}
 	sort.Sort(OrderSecurityGroupsById(actual.SecurityGroups))
 
@@ -269,7 +269,7 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 
 	// @step: get the image is order to find out the root device name as using the index
 	// is not variable, under conditions they move
-	image, err := cloud.ResolveImage(fi.StringValue(t.ImageID))
+	image, err := cloud.ResolveImage(fi.ValueOf(t.ImageID))
 	if err != nil {
 		return nil, err
 	}
@@ -279,7 +279,7 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 		if b.Ebs == nil {
 			continue
 		}
-		if b.DeviceName != nil && fi.StringValue(b.DeviceName) == fi.StringValue(image.RootDeviceName) {
+		if b.DeviceName != nil && fi.ValueOf(b.DeviceName) == fi.ValueOf(image.RootDeviceName) {
 			actual.RootVolumeSize = b.Ebs.VolumeSize
 			actual.RootVolumeType = b.Ebs.VolumeType
 			actual.RootVolumeIops = b.Ebs.Iops
@@ -288,7 +288,7 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 			if b.Ebs.KmsKeyId != nil {
 				actual.RootVolumeKmsKey = b.Ebs.KmsKeyId
 			} else {
-				actual.RootVolumeKmsKey = fi.String("")
+				actual.RootVolumeKmsKey = fi.PtrTo("")
 			}
 		} else {
 			_, d := BlockDeviceMappingFromLaunchTemplateBootDeviceRequest(b)
@@ -341,10 +341,10 @@ func (t *LaunchTemplate) Find(c *fi.Context) (*LaunchTemplate, error) {
 }
 
 // findAllLaunchTemplates returns all the launch templates for us
-func (t *LaunchTemplate) findAllLaunchTemplates(c *fi.Context) ([]*ec2.LaunchTemplate, error) {
-	cloud, ok := c.Cloud.(awsup.AWSCloud)
+func (t *LaunchTemplate) findAllLaunchTemplates(c *fi.CloudupContext) ([]*ec2.LaunchTemplate, error) {
+	cloud, ok := c.T.Cloud.(awsup.AWSCloud)
 	if !ok {
-		return nil, fmt.Errorf("invalid cloud provider: %v, expected: %s", c.Cloud, "awsup.AWSCloud")
+		return nil, fmt.Errorf("invalid cloud provider: %v, expected: %s", c.T.Cloud, "awsup.AWSCloud")
 	}
 
 	input := &ec2.DescribeLaunchTemplatesInput{
@@ -369,10 +369,10 @@ func (t *LaunchTemplate) findAllLaunchTemplates(c *fi.Context) ([]*ec2.LaunchTem
 }
 
 // findLatestLaunchTemplateVersion returns the latest template version
-func (t *LaunchTemplate) findLatestLaunchTemplateVersion(c *fi.Context) (*ec2.LaunchTemplateVersion, error) {
-	cloud, ok := c.Cloud.(awsup.AWSCloud)
+func (t *LaunchTemplate) findLatestLaunchTemplateVersion(c *fi.CloudupContext) (*ec2.LaunchTemplateVersion, error) {
+	cloud, ok := c.T.Cloud.(awsup.AWSCloud)
 	if !ok {
-		return nil, fmt.Errorf("invalid cloud provider: %v, expected: awsup.AWSCloud", c.Cloud)
+		return nil, fmt.Errorf("invalid cloud provider: %v, expected: awsup.AWSCloud", c.T.Cloud)
 	}
 
 	input := &ec2.DescribeLaunchTemplateVersionsInput{
@@ -403,7 +403,7 @@ type deleteLaunchTemplate struct {
 	lc *ec2.LaunchTemplate
 }
 
-var _ fi.Deletion = &deleteLaunchTemplate{}
+var _ fi.CloudupDeletion = &deleteLaunchTemplate{}
 
 // TaskName returns the task name
 func (d *deleteLaunchTemplate) TaskName() string {
@@ -412,10 +412,10 @@ func (d *deleteLaunchTemplate) TaskName() string {
 
 // Item returns the launch template name
 func (d *deleteLaunchTemplate) Item() string {
-	return fi.StringValue(d.lc.LaunchTemplateName)
+	return fi.ValueOf(d.lc.LaunchTemplateName)
 }
 
-func (d *deleteLaunchTemplate) Delete(t fi.Target) error {
+func (d *deleteLaunchTemplate) Delete(t fi.CloudupTarget) error {
 	awsTarget, ok := t.(*awsup.AWSAPITarget)
 	if !ok {
 		return fmt.Errorf("unexpected target type for deletion: %T", t)
