@@ -26,7 +26,6 @@ import (
 	raws "k8s.io/kops/pkg/resources/aws"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -59,12 +58,12 @@ func (e *NatGateway) CompareWithID() *string {
 	return e.ID
 }
 
-func (e *NatGateway) Find(c *fi.Context) (*NatGateway, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *NatGateway) Find(c *fi.CloudupContext) (*NatGateway, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 	var ngw *ec2.NatGateway
 	actual := &NatGateway{}
 
-	if fi.StringValue(e.ID) != "" {
+	if fi.ValueOf(e.ID) != "" {
 		// We have an existing NGW, lets look up the EIP
 		var ngwIds []*string
 		ngwIds = append(ngwIds, e.ID)
@@ -79,7 +78,7 @@ func (e *NatGateway) Find(c *fi.Context) (*NatGateway, error) {
 		}
 
 		if len(response.NatGateways) != 1 {
-			return nil, fmt.Errorf("found %d Nat Gateways with ID %q, expected 1", len(response.NatGateways), fi.StringValue(e.ID))
+			return nil, fmt.Errorf("found %d Nat Gateways with ID %q, expected 1", len(response.NatGateways), fi.ValueOf(e.ID))
 		}
 		ngw = response.NatGateways[0]
 
@@ -127,8 +126,8 @@ func (e *NatGateway) Find(c *fi.Context) (*NatGateway, error) {
 	return actual, nil
 }
 
-func (e *NatGateway) findNatGateway(c *fi.Context) (*ec2.NatGateway, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *NatGateway) findNatGateway(c *fi.CloudupContext) (*ec2.NatGateway, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	id := e.ID
 
@@ -211,9 +210,11 @@ func findNatGatewayFromRouteTable(cloud awsup.AWSCloud, routeTable *RouteTable)
 
 		if rt != nil {
 			var natGatewayIDs []*string
+			natGatewayIDsSeen := map[string]bool{}
 			for _, route := range rt.Routes {
-				if route.NatGatewayId != nil {
+				if route.NatGatewayId != nil && !natGatewayIDsSeen[*route.NatGatewayId] {
 					natGatewayIDs = append(natGatewayIDs, route.NatGatewayId)
+					natGatewayIDsSeen[*route.NatGatewayId] = true
 				}
 			}
 
@@ -231,7 +232,7 @@ func findNatGatewayFromRouteTable(cloud awsup.AWSCloud, routeTable *RouteTable)
 						return nil, err
 					}
 
-					if raws.HasOwnedTag(ec2.ResourceTypeNatgateway+":"+fi.StringValue(natGatewayID), gw.Tags, clusterName) {
+					if raws.HasOwnedTag(ec2.ResourceTypeNatgateway+":"+fi.ValueOf(natGatewayID), gw.Tags, clusterName) {
 						filteredNatGateways = append(filteredNatGateways, gw)
 					}
 				}
@@ -254,7 +255,7 @@ func findNatGatewayFromRouteTable(cloud awsup.AWSCloud, routeTable *RouteTable)
 func (s *NatGateway) CheckChanges(a, e, changes *NatGateway) error {
 	// New
 	if a == nil {
-		if !fi.BoolValue(e.Shared) {
+		if !fi.ValueOf(e.Shared) {
 			if e.ElasticIP == nil {
 				return fi.RequiredField("ElasticIP")
 			}
@@ -272,11 +273,11 @@ func (s *NatGateway) CheckChanges(a, e, changes *NatGateway) error {
 		if changes.ElasticIP != nil {
 			eID := ""
 			if e.ElasticIP != nil {
-				eID = fi.StringValue(e.ElasticIP.ID)
+				eID = fi.ValueOf(e.ElasticIP.ID)
 			}
 			aID := ""
 			if a.ElasticIP != nil {
-				aID = fi.StringValue(a.ElasticIP.ID)
+				aID = fi.ValueOf(a.ElasticIP.ID)
 			}
 			return fi.FieldIsImmutable(eID, aID, field.NewPath("ElasticIP"))
 		}
@@ -290,8 +291,8 @@ func (s *NatGateway) CheckChanges(a, e, changes *NatGateway) error {
 	return nil
 }
 
-func (e *NatGateway) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *NatGateway) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *NatGateway) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *NatGateway) error {
@@ -300,8 +301,8 @@ func (_ *NatGateway) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *NatGateway)
 	var id *string
 	if a == nil {
 
-		if fi.BoolValue(e.Shared) {
-			return fmt.Errorf("NAT gateway %q not found", fi.StringValue(e.ID))
+		if fi.ValueOf(e.Shared) {
+			return fmt.Errorf("NAT gateway %q not found", fi.ValueOf(e.ID))
 		}
 
 		klog.V(2).Infof("Creating Nat Gateway")
@@ -346,12 +347,12 @@ func (_ *NatGateway) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *NatGateway)
 	// This is better than just a tag that's shared because this lets us create a whitelist of these NGWs
 	// without doing a bunch more work in `kutil/delete_cluster.go`
 
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		if e.AssociatedRouteTable == nil {
 			return fmt.Errorf("AssociatedRouteTable not provided")
 		}
-		klog.V(2).Infof("tagging route table %s to track shared NGW", fi.StringValue(e.AssociatedRouteTable.ID))
-		err = t.AddAWSTags(fi.StringValue(e.AssociatedRouteTable.ID), tags)
+		klog.V(2).Infof("tagging route table %s to track shared NGW", fi.ValueOf(e.AssociatedRouteTable.ID))
+		err = t.AddAWSTags(fi.ValueOf(e.AssociatedRouteTable.ID), tags)
 		if err != nil {
 			return fmt.Errorf("unable to tag route table %v", err)
 		}
@@ -367,7 +368,7 @@ type terraformNATGateway struct {
 }
 
 func (_ *NatGateway) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *NatGateway) error {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		if e.ID == nil {
 			return fmt.Errorf("ID must be set, if NatGateway is shared: %s", e)
 		}
@@ -386,7 +387,7 @@ func (_ *NatGateway) RenderTerraform(t *terraform.TerraformTarget, a, e, changes
 }
 
 func (e *NatGateway) TerraformLink() *terraformWriter.Literal {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		if e.ID == nil {
 			klog.Fatalf("ID must be set, if NatGateway is shared: %s", e)
 		}
@@ -396,40 +397,3 @@ func (e *NatGateway) TerraformLink() *terraformWriter.Literal {
 
 	return terraformWriter.LiteralProperty("aws_nat_gateway", *e.Name, "id")
 }
-
-type cloudformationNATGateway struct {
-	AllocationID *cloudformation.Literal `json:"AllocationId,omitempty"`
-	SubnetID     *cloudformation.Literal `json:"SubnetId,omitempty"`
-	Tags         []cloudformationTag     `json:"Tags,omitempty"`
-}
-
-func (_ *NatGateway) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *NatGateway) error {
-	if fi.BoolValue(e.Shared) {
-		if e.ID == nil {
-			return fmt.Errorf("ID must be set, if NatGateway is shared: %s", e)
-		}
-
-		klog.V(4).Infof("reusing existing NatGateway with id %q", *e.ID)
-		return nil
-	}
-
-	cf := &cloudformationNATGateway{
-		AllocationID: e.ElasticIP.CloudformationAllocationID(),
-		SubnetID:     e.Subnet.CloudformationLink(),
-		Tags:         buildCloudformationTags(e.Tags),
-	}
-
-	return t.RenderResource("AWS::EC2::NatGateway", *e.Name, cf)
-}
-
-func (e *NatGateway) CloudformationLink() *cloudformation.Literal {
-	if fi.BoolValue(e.Shared) {
-		if e.ID == nil {
-			klog.Fatalf("ID must be set, if NatGateway is shared: %s", e)
-		}
-
-		return cloudformation.LiteralString(*e.ID)
-	}
-
-	return cloudformation.Ref("AWS::EC2::NatGateway", *e.Name)
-}
