@@ -479,6 +479,16 @@ func (e *NetworkLoadBalancer) Normalize(c *fi.CloudupContext) error {
 	sort.Stable(OrderSubnetMappingsByName(e.SubnetMappings))
 	sort.Stable(OrderListenersByPort(e.Listeners))
 	sort.Stable(OrderTargetGroupsByName(e.TargetGroups))
+
+	e.IpAddressType = fi.PtrTo("dualstack")
+	for _, subnet := range e.SubnetMappings {
+		for _, clusterSubnet := range c.T.Cluster.Spec.Networking.Subnets {
+			if clusterSubnet.Name == fi.ValueOf(subnet.Subnet.ShortName) && clusterSubnet.IPv6CIDR == "" {
+				e.IpAddressType = fi.PtrTo("ipv4")
+			}
+		}
+	}
+
 	return nil
 }
 
@@ -733,6 +743,7 @@ type terraformNetworkLoadBalancer struct {
 	Name                   string                                      `cty:"name"`
 	Internal               bool                                        `cty:"internal"`
 	Type                   string                                      `cty:"load_balancer_type"`
+	IPAddressType          *string                                     `cty:"ip_address_type"`
 	SubnetMappings         []terraformNetworkLoadBalancerSubnetMapping `cty:"subnet_mapping"`
 	CrossZoneLoadBalancing bool                                        `cty:"enable_cross_zone_load_balancing"`
 	AccessLog              *terraformNetworkLoadBalancerAccessLog      `cty:"access_logs"`
@@ -768,6 +779,9 @@ func (_ *NetworkLoadBalancer) RenderTerraform(t *terraform.TerraformTarget, a, e
 		Tags:                   e.Tags,
 		CrossZoneLoadBalancing: fi.ValueOf(e.CrossZoneLoadBalancing),
 	}
+	if fi.ValueOf(e.IpAddressType) == "dualstack" {
+		nlbTF.IPAddressType = e.IpAddressType
+	}
 
 	for _, subnetMapping := range e.SubnetMappings {
 		nlbTF.SubnetMappings = append(nlbTF.SubnetMappings, terraformNetworkLoadBalancerSubnetMapping{
