@@ -26,7 +26,6 @@ import (
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -49,8 +48,8 @@ type SecurityGroup struct {
 }
 
 var (
-	_ fi.CompareWithID     = &SecurityGroup{}
-	_ fi.ProducesDeletions = &SecurityGroup{}
+	_ fi.CompareWithID            = &SecurityGroup{}
+	_ fi.CloudupProducesDeletions = &SecurityGroup{}
 )
 
 func (e *SecurityGroup) CompareWithID() *string {
@@ -63,10 +62,10 @@ type OrderSecurityGroupsById []*SecurityGroup
 func (a OrderSecurityGroupsById) Len() int      { return len(a) }
 func (a OrderSecurityGroupsById) Swap(i, j int) { a[i], a[j] = a[j], a[i] }
 func (a OrderSecurityGroupsById) Less(i, j int) bool {
-	return fi.StringValue(a[i].ID) < fi.StringValue(a[j].ID)
+	return fi.ValueOf(a[i].ID) < fi.ValueOf(a[j].ID)
 }
 
-func (e *SecurityGroup) Find(c *fi.Context) (*SecurityGroup, error) {
+func (e *SecurityGroup) Find(c *fi.CloudupContext) (*SecurityGroup, error) {
 	sg, err := e.findEc2(c)
 	if err != nil {
 		return nil, err
@@ -97,14 +96,14 @@ func (e *SecurityGroup) Find(c *fi.Context) (*SecurityGroup, error) {
 	return actual, nil
 }
 
-func (e *SecurityGroup) findEc2(c *fi.Context) (*ec2.SecurityGroup, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *SecurityGroup) findEc2(c *fi.CloudupContext) (*ec2.SecurityGroup, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 	request := &ec2.DescribeSecurityGroupsInput{}
 
-	if fi.StringValue(e.ID) != "" {
+	if fi.ValueOf(e.ID) != "" {
 		// Find by ID.
 		request.GroupIds = []*string{e.ID}
-	} else if fi.StringValue(e.Name) != "" && e.VPC != nil && e.VPC.ID != nil {
+	} else if fi.ValueOf(e.Name) != "" && e.VPC != nil && e.VPC.ID != nil {
 		// Find by filters (name and VPC ID).
 		filters := cloud.BuildFilters(e.Name)
 		filters = append(filters, awsup.NewEC2Filter("vpc-id", *e.VPC.ID))
@@ -131,12 +130,12 @@ func (e *SecurityGroup) findEc2(c *fi.Context) (*ec2.SecurityGroup, error) {
 	return sg, nil
 }
 
-func (e *SecurityGroup) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *SecurityGroup) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *SecurityGroup) ShouldCreate(a, e, changes *SecurityGroup) (bool, error) {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		return false, nil
 	}
 	return true, nil
@@ -147,7 +146,7 @@ func (_ *SecurityGroup) CheckChanges(a, e, changes *SecurityGroup) error {
 		if changes.ID != nil {
 			return fi.CannotChangeField("ID")
 		}
-		if changes.Name != nil && !fi.BoolValue(e.Shared) {
+		if changes.Name != nil && !fi.ValueOf(e.Shared) {
 			return fi.CannotChangeField("Name")
 		}
 		if changes.VPC != nil {
@@ -158,7 +157,7 @@ func (_ *SecurityGroup) CheckChanges(a, e, changes *SecurityGroup) error {
 }
 
 func (_ *SecurityGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *SecurityGroup) error {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		// Do we want to do any verification of the security group?
 		return nil
@@ -193,7 +192,7 @@ type terraformSecurityGroup struct {
 }
 
 func (_ *SecurityGroup) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *SecurityGroup) error {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		// Not terraform owned / managed
 		return nil
@@ -210,7 +209,7 @@ func (_ *SecurityGroup) RenderTerraform(t *terraform.TerraformTarget, a, e, chan
 }
 
 func (e *SecurityGroup) TerraformLink() *terraformWriter.Literal {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		// Not terraform owned / managed
 		if e.ID != nil {
@@ -223,51 +222,13 @@ func (e *SecurityGroup) TerraformLink() *terraformWriter.Literal {
 	return terraformWriter.LiteralProperty("aws_security_group", *e.Name, "id")
 }
 
-type cloudformationSecurityGroup struct {
-	GroupName   *string                 `json:"GroupName"`
-	VpcId       *cloudformation.Literal `json:"VpcId"`
-	Description *string                 `json:"GroupDescription"`
-	Tags        []cloudformationTag     `json:"Tags,omitempty"`
-}
-
-func (_ *SecurityGroup) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *SecurityGroup) error {
-	shared := fi.BoolValue(e.Shared)
-	if shared {
-		// Not cloudformation owned / managed
-		return nil
-	}
-
-	tf := &cloudformationSecurityGroup{
-		GroupName:   e.Name,
-		VpcId:       e.VPC.CloudformationLink(),
-		Description: e.Description,
-		Tags:        buildCloudformationTags(e.Tags),
-	}
-
-	return t.RenderResource("AWS::EC2::SecurityGroup", *e.Name, tf)
-}
-
-func (e *SecurityGroup) CloudformationLink() *cloudformation.Literal {
-	shared := fi.BoolValue(e.Shared)
-	if shared {
-		// Not cloudformation owned / managed
-		if e.ID != nil {
-			return cloudformation.LiteralString(*e.ID)
-		} else {
-			klog.Warningf("ID not set on shared subnet %v", e)
-		}
-	}
-
-	return cloudformation.Ref("AWS::EC2::SecurityGroup", *e.Name)
-}
-
 type deleteSecurityGroupRule struct {
 	rule *ec2.SecurityGroupRule
 }
 
-var _ fi.Deletion = &deleteSecurityGroupRule{}
+var _ fi.CloudupDeletion = &deleteSecurityGroupRule{}
 
-func (d *deleteSecurityGroupRule) Delete(t fi.Target) error {
+func (d *deleteSecurityGroupRule) Delete(t fi.CloudupTarget) error {
 	klog.V(2).Infof("deleting security group permission: %v", fi.DebugAsJsonString(d.rule))
 
 	awsTarget, ok := t.(*awsup.AWSAPITarget)
@@ -275,7 +236,7 @@ func (d *deleteSecurityGroupRule) Delete(t fi.Target) error {
 		return fmt.Errorf("unexpected target type for deletion: %T", t)
 	}
 
-	if fi.BoolValue(d.rule.IsEgress) {
+	if fi.ValueOf(d.rule.IsEgress) {
 		request := &ec2.RevokeSecurityGroupEgressInput{
 			GroupId:              d.rule.GroupId,
 			SecurityGroupRuleIds: []*string{d.rule.SecurityGroupRuleId},
@@ -307,7 +268,7 @@ func (d *deleteSecurityGroupRule) TaskName() string {
 }
 
 func (d *deleteSecurityGroupRule) Item() string {
-	s := fi.StringValue(d.rule.GroupId) + ":"
+	s := fi.ValueOf(d.rule.GroupId) + ":"
 	p := d.rule
 	if aws.Int64Value(p.FromPort) != 0 {
 		s += fmt.Sprintf(" port=%d", aws.Int64Value(p.FromPort))
@@ -329,8 +290,8 @@ func (d *deleteSecurityGroupRule) Item() string {
 	return s
 }
 
-func (e *SecurityGroup) FindDeletions(c *fi.Context) ([]fi.Deletion, error) {
-	var removals []fi.Deletion
+func (e *SecurityGroup) FindDeletions(c *fi.CloudupContext) ([]fi.CloudupDeletion, error) {
+	var removals []fi.CloudupDeletion
 
 	if len(e.RemoveExtraRules) == 0 {
 		return nil, nil
@@ -353,7 +314,7 @@ func (e *SecurityGroup) FindDeletions(c *fi.Context) ([]fi.Deletion, error) {
 		return nil, nil
 	}
 
-	cloud := c.Cloud.(awsup.AWSCloud)
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	request := &ec2.DescribeSecurityGroupRulesInput{
 		Filters: []*ec2.Filter{
@@ -390,7 +351,7 @@ func (e *SecurityGroup) FindDeletions(c *fi.Context) ([]fi.Deletion, error) {
 			}
 
 			if er.SourceGroup != nil && er.SourceGroup.ID == nil {
-				klog.V(4).Infof("Deletion skipping find of SecurityGroupRule %s, because SourceGroup was not found", fi.StringValue(er.Name))
+				klog.V(4).Infof("Deletion skipping find of SecurityGroupRule %s, because SourceGroup was not found", fi.ValueOf(er.Name))
 				return nil, nil
 			}
 
