@@ -19,17 +19,26 @@ package awstasks
 import (
 	"fmt"
 
-	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/awserr"
 	"github.com/aws/aws-sdk-go/service/elbv2"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
 
+const (
+	// TargetGroupAttributeDeregistrationDelayConnectionTerminationEnabled indicates whether
+	//the load balancer terminates connections at the end of the deregistration timeout.
+	// https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html#deregistration-delay
+	TargetGroupAttributeDeregistrationDelayConnectionTerminationEnabled = "deregistration_delay.connection_termination.enabled"
+	// TargetGroupAttributeDeregistrationDelayTimeoutSeconds is the amount of time for Elastic Load Balancing
+	// to wait before changing the state of a deregistering target from draining to unused.
+	// https://docs.aws.amazon.com/elasticloadbalancing/latest/network/load-balancer-target-groups.html#deregistration-delay
+	TargetGroupAttributeDeregistrationDelayTimeoutSeconds = "deregistration_delay.timeout_seconds"
+)
+
 // +kops:fitask
 type TargetGroup struct {
 	Name      *string
@@ -45,6 +54,9 @@ type TargetGroup struct {
 	// Shared is set if this is an external LB (one we don't create or own)
 	Shared *bool
 
+	Attributes map[string]string
+
+	Interval           *int64
 	HealthyThreshold   *int64
 	UnhealthyThreshold *int64
 }
@@ -55,8 +67,8 @@ func (e *TargetGroup) CompareWithID() *string {
 	return e.ARN
 }
 
-func (e *TargetGroup) Find(c *fi.Context) (*TargetGroup, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *TargetGroup) Find(c *fi.CloudupContext) (*TargetGroup, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	request := &elbv2.DescribeTargetGroupsInput{}
 	if e.ARN != nil {
@@ -68,7 +80,7 @@ func (e *TargetGroup) Find(c *fi.Context) (*TargetGroup, error) {
 	response, err := cloud.ELBV2().DescribeTargetGroups(request)
 	if err != nil {
 		if aerr, ok := err.(awserr.Error); ok && aerr.Code() == elbv2.ErrCodeTargetGroupNotFoundException {
-			if !fi.BoolValue(e.Shared) {
+			if !fi.ValueOf(e.Shared) {
 				return nil, nil
 			}
 		}
@@ -76,7 +88,7 @@ func (e *TargetGroup) Find(c *fi.Context) (*TargetGroup, error) {
 	}
 
 	if len(response.TargetGroups) > 1 {
-		return nil, fmt.Errorf("found %d TargetGroups with ID %q, expected 1", len(response.TargetGroups), fi.StringValue(e.Name))
+		return nil, fmt.Errorf("found %d TargetGroups with ID %q, expected 1", len(response.TargetGroups), fi.ValueOf(e.Name))
 	} else if len(response.TargetGroups) == 0 {
 		return nil, nil
 	}
@@ -88,10 +100,14 @@ func (e *TargetGroup) Find(c *fi.Context) (*TargetGroup, error) {
 		Port:               tg.Port,
 		Protocol:           tg.Protocol,
 		ARN:                tg.TargetGroupArn,
+		Interval:           tg.HealthCheckIntervalSeconds,
 		HealthyThreshold:   tg.HealthyThresholdCount,
 		UnhealthyThreshold: tg.UnhealthyThresholdCount,
 		VPC:                &VPC{ID: tg.VpcId},
 	}
+	// Interval cannot be changed after TargetGroup creation
+	e.Interval = actual.Interval
+
 	e.ARN = tg.TargetGroupArn
 
 	tagsResp, err := cloud.ELBV2().DescribeTags(&elbv2.DescribeTagsInput{
@@ -103,11 +119,27 @@ func (e *TargetGroup) Find(c *fi.Context) (*TargetGroup, error) {
 	tags := make(map[string]string)
 	for _, tagDesc := range tagsResp.TagDescriptions {
 		for _, tag := range tagDesc.Tags {
-			tags[fi.StringValue(tag.Key)] = fi.StringValue(tag.Value)
+			tags[fi.ValueOf(tag.Key)] = fi.ValueOf(tag.Value)
 		}
 	}
 	actual.Tags = tags
 
+	attrResp, err := cloud.ELBV2().DescribeTargetGroupAttributes(&elbv2.DescribeTargetGroupAttributesInput{
+		TargetGroupArn: tg.TargetGroupArn,
+	})
+	if err != nil {
+		return nil, err
+	}
+	attributes := make(map[string]string)
+	for _, attr := range attrResp.Attributes {
+		if _, ok := e.Attributes[fi.ValueOf(attr.Key)]; ok {
+			attributes[fi.ValueOf(attr.Key)] = fi.ValueOf(attr.Value)
+		}
+	}
+	if len(attributes) > 0 {
+		actual.Attributes = attributes
+	}
+
 	// Prevent spurious changes
 	actual.Lifecycle = e.Lifecycle
 	actual.Shared = e.Shared
@@ -115,39 +147,12 @@ func (e *TargetGroup) Find(c *fi.Context) (*TargetGroup, error) {
 	return actual, nil
 }
 
-func FindTargetGroupByName(cloud awsup.AWSCloud, findName string) (*elbv2.TargetGroup, error) {
-	klog.V(2).Infof("Listing all TargetGroups for FindTargetGroupByName")
-
-	request := &elbv2.DescribeTargetGroupsInput{
-		Names: []*string{aws.String(findName)},
-	}
-	// ELB DescribeTags has a limit of 20 names, so we set the page size here to 20 also
-	request.PageSize = aws.Int64(20)
-
-	resp, err := cloud.ELBV2().DescribeTargetGroups(request)
-	if err != nil {
-		if aerr, ok := err.(awserr.Error); ok && aerr.Code() == elbv2.ErrCodeTargetGroupNotFoundException {
-			return nil, nil
-		}
-		return nil, fmt.Errorf("error describing TargetGroups: %v", err)
-	}
-	if len(resp.TargetGroups) == 0 {
-		return nil, nil
-	}
-
-	if len(resp.TargetGroups) != 1 {
-		return nil, fmt.Errorf("Found multiple TargetGroups with Name %q", findName)
-	}
-
-	return resp.TargetGroups[0], nil
-}
-
-func (e *TargetGroup) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *TargetGroup) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *TargetGroup) ShouldCreate(a, e, changes *TargetGroup) (bool, error) {
-	if fi.BoolValue(e.Shared) {
+	if fi.ValueOf(e.Shared) {
 		return false, nil
 	}
 	return true, nil
@@ -158,7 +163,7 @@ func (s *TargetGroup) CheckChanges(a, e, changes *TargetGroup) error {
 }
 
 func (_ *TargetGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *TargetGroup) error {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		return nil
 	}
@@ -169,13 +174,14 @@ func (_ *TargetGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *TargetGrou
 
 	if a == nil {
 		request := &elbv2.CreateTargetGroupInput{
-			Name:                    e.Name,
-			Port:                    e.Port,
-			Protocol:                e.Protocol,
-			VpcId:                   e.VPC.ID,
-			HealthyThresholdCount:   e.HealthyThreshold,
-			UnhealthyThresholdCount: e.UnhealthyThreshold,
-			Tags:                    awsup.ELBv2Tags(e.Tags),
+			Name:                       e.Name,
+			Port:                       e.Port,
+			Protocol:                   e.Protocol,
+			VpcId:                      e.VPC.ID,
+			HealthCheckIntervalSeconds: e.Interval,
+			HealthyThresholdCount:      e.HealthyThreshold,
+			UnhealthyThresholdCount:    e.UnhealthyThreshold,
+			Tags:                       awsup.ELBv2Tags(e.Tags),
 		}
 
 		klog.V(2).Infof("Creating Target Group for NLB")
@@ -184,11 +190,19 @@ func (_ *TargetGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *TargetGrou
 			return fmt.Errorf("Error creating target group for NLB : %v", err)
 		}
 
-		targetGroupArn := *response.TargetGroups[0].TargetGroupArn
-		e.ARN = fi.String(targetGroupArn)
+		if err := ModifyTargetGroupAttributes(t.Cloud, response.TargetGroups[0].TargetGroupArn, e.Attributes); err != nil {
+			return err
+		}
+
+		// Avoid spurious changes
+		e.ARN = response.TargetGroups[0].TargetGroupArn
+
 	} else {
 		if a.ARN != nil {
-			if err := t.AddELBV2Tags(fi.StringValue(a.ARN), e.Tags); err != nil {
+			if err := t.AddELBV2Tags(fi.ValueOf(a.ARN), e.Tags); err != nil {
+				return err
+			}
+			if err := ModifyTargetGroupAttributes(t.Cloud, a.ARN, e.Attributes); err != nil {
 				return err
 			}
 		}
@@ -196,32 +210,53 @@ func (_ *TargetGroup) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *TargetGrou
 	return nil
 }
 
+func ModifyTargetGroupAttributes(cloud awsup.AWSCloud, arn *string, attributes map[string]string) error {
+	klog.V(2).Infof("Modifying Target Group attributes for NLB")
+	attrReq := &elbv2.ModifyTargetGroupAttributesInput{
+		Attributes:     []*elbv2.TargetGroupAttribute{},
+		TargetGroupArn: arn,
+	}
+	for k, v := range attributes {
+		attrReq.Attributes = append(attrReq.Attributes, &elbv2.TargetGroupAttribute{
+			Key:   fi.PtrTo(k),
+			Value: fi.PtrTo(v),
+		})
+	}
+	if _, err := cloud.ELBV2().ModifyTargetGroupAttributes(attrReq); err != nil {
+		return fmt.Errorf("error modifying target group attributes for NLB : %v", err)
+	}
+	return nil
+}
+
 // OrderTargetGroupsByName implements sort.Interface for []OrderTargetGroupsByName, based on port number
 type OrderTargetGroupsByName []*TargetGroup
 
 func (a OrderTargetGroupsByName) Len() int      { return len(a) }
 func (a OrderTargetGroupsByName) Swap(i, j int) { a[i], a[j] = a[j], a[i] }
 func (a OrderTargetGroupsByName) Less(i, j int) bool {
-	return fi.StringValue(a[i].Name) < fi.StringValue(a[j].Name)
+	return fi.ValueOf(a[i].Name) < fi.ValueOf(a[j].Name)
 }
 
 type terraformTargetGroup struct {
-	Name        string                          `cty:"name"`
-	Port        int64                           `cty:"port"`
-	Protocol    string                          `cty:"protocol"`
-	VPCID       terraformWriter.Literal         `cty:"vpc_id"`
-	Tags        map[string]string               `cty:"tags"`
-	HealthCheck terraformTargetGroupHealthCheck `cty:"health_check"`
+	Name                  string                          `cty:"name"`
+	Port                  int64                           `cty:"port"`
+	Protocol              string                          `cty:"protocol"`
+	VPCID                 *terraformWriter.Literal        `cty:"vpc_id"`
+	ConnectionTermination string                          `cty:"connection_termination"`
+	DeregistrationDelay   string                          `cty:"deregistration_delay"`
+	Tags                  map[string]string               `cty:"tags"`
+	HealthCheck           terraformTargetGroupHealthCheck `cty:"health_check"`
 }
 
 type terraformTargetGroupHealthCheck struct {
+	Interval           int64  `cty:"interval"`
 	HealthyThreshold   int64  `cty:"healthy_threshold"`
 	UnhealthyThreshold int64  `cty:"unhealthy_threshold"`
 	Protocol           string `cty:"protocol"`
 }
 
 func (_ *TargetGroup) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *TargetGroup) error {
-	shared := fi.BoolValue(e.Shared)
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		return nil
 	}
@@ -234,20 +269,30 @@ func (_ *TargetGroup) RenderTerraform(t *terraform.TerraformTarget, a, e, change
 		Name:     *e.Name,
 		Port:     *e.Port,
 		Protocol: *e.Protocol,
-		VPCID:    *e.VPC.TerraformLink(),
+		VPCID:    e.VPC.TerraformLink(),
 		Tags:     e.Tags,
 		HealthCheck: terraformTargetGroupHealthCheck{
+			Interval:           *e.Interval,
 			HealthyThreshold:   *e.HealthyThreshold,
 			UnhealthyThreshold: *e.UnhealthyThreshold,
 			Protocol:           elbv2.ProtocolEnumTcp,
 		},
 	}
 
+	for attr, val := range e.Attributes {
+		if attr == TargetGroupAttributeDeregistrationDelayConnectionTerminationEnabled {
+			tf.ConnectionTermination = val
+		}
+		if attr == TargetGroupAttributeDeregistrationDelayTimeoutSeconds {
+			tf.DeregistrationDelay = val
+		}
+	}
+
 	return t.RenderResource("aws_lb_target_group", *e.Name, tf)
 }
 
-func (e *TargetGroup) TerraformLink(params ...string) *terraformWriter.Literal {
-	shared := fi.BoolValue(e.Shared)
+func (e *TargetGroup) TerraformLink() *terraformWriter.Literal {
+	shared := fi.ValueOf(e.Shared)
 	if shared {
 		if e.ARN != nil {
 			return terraformWriter.LiteralFromStringValue(*e.ARN)
@@ -257,47 +302,3 @@ func (e *TargetGroup) TerraformLink(params ...string) *terraformWriter.Literal {
 	}
 	return terraformWriter.LiteralProperty("aws_lb_target_group", *e.Name, "id")
 }
-
-type cloudformationTargetGroup struct {
-	Name     string                  `json:"Name"`
-	Port     int64                   `json:"Port"`
-	Protocol string                  `json:"Protocol"`
-	VPCID    *cloudformation.Literal `json:"VpcId"`
-	Tags     []cloudformationTag     `json:"Tags"`
-
-	HealthCheckProtocol string `json:"HealthCheckProtocol"`
-	HealthyThreshold    int64  `json:"HealthyThresholdCount"`
-	UnhealthyThreshold  int64  `json:"UnhealthyThresholdCount"`
-}
-
-func (_ *TargetGroup) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *TargetGroup) error {
-	shared := fi.BoolValue(e.Shared)
-	if shared {
-		return nil
-	}
-
-	cf := &cloudformationTargetGroup{
-		Name:                *e.Name,
-		Port:                *e.Port,
-		Protocol:            *e.Protocol,
-		VPCID:               e.VPC.CloudformationLink(),
-		Tags:                buildCloudformationTags(e.Tags),
-		HealthCheckProtocol: *e.Protocol,
-		HealthyThreshold:    *e.HealthyThreshold,
-		UnhealthyThreshold:  *e.UnhealthyThreshold,
-	}
-	return t.RenderResource("AWS::ElasticLoadBalancingV2::TargetGroup", *e.Name, cf)
-}
-
-func (e *TargetGroup) CloudformationLink() *cloudformation.Literal {
-	shared := fi.BoolValue(e.Shared)
-	if shared {
-		if e.ARN != nil {
-			return cloudformation.LiteralString(*e.ARN)
-		} else {
-			klog.Warningf("ID not set on shared Target Group: %v", e)
-		}
-	}
-
-	return cloudformation.Ref("AWS::ElasticLoadBalancingV2::TargetGroup", *e.Name)
-}
