@@ -23,7 +23,6 @@ import (
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
-	"k8s.io/kops/upup/pkg/fi/cloudup/cloudformation"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraform"
 	"k8s.io/kops/upup/pkg/fi/cloudup/terraformWriter"
 )
@@ -37,8 +36,8 @@ type VPCDHCPOptionsAssociation struct {
 	DHCPOptions *DHCPOptions
 }
 
-func (e *VPCDHCPOptionsAssociation) Find(c *fi.Context) (*VPCDHCPOptionsAssociation, error) {
-	cloud := c.Cloud.(awsup.AWSCloud)
+func (e *VPCDHCPOptionsAssociation) Find(c *fi.CloudupContext) (*VPCDHCPOptionsAssociation, error) {
+	cloud := c.T.Cloud.(awsup.AWSCloud)
 
 	vpcID := e.VPC.ID
 	dhcpOptionsID := e.DHCPOptions.ID
@@ -63,8 +62,8 @@ func (e *VPCDHCPOptionsAssociation) Find(c *fi.Context) (*VPCDHCPOptionsAssociat
 	return actual, nil
 }
 
-func (e *VPCDHCPOptionsAssociation) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *VPCDHCPOptionsAssociation) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(e, c)
 }
 
 func (s *VPCDHCPOptionsAssociation) CheckChanges(a, e, changes *VPCDHCPOptionsAssociation) error {
@@ -115,17 +114,3 @@ func (_ *VPCDHCPOptionsAssociation) RenderTerraform(t *terraform.TerraformTarget
 
 	return t.RenderResource("aws_vpc_dhcp_options_association", *e.Name, tf)
 }
-
-type cloudformationVPCDHCPOptionsAssociation struct {
-	VpcId         *cloudformation.Literal `json:"VpcId"`
-	DhcpOptionsId *cloudformation.Literal `json:"DhcpOptionsId"`
-}
-
-func (_ *VPCDHCPOptionsAssociation) RenderCloudformation(t *cloudformation.CloudformationTarget, a, e, changes *VPCDHCPOptionsAssociation) error {
-	tf := &cloudformationVPCDHCPOptionsAssociation{
-		VpcId:         e.VPC.CloudformationLink(),
-		DhcpOptionsId: e.DHCPOptions.CloudformationLink(),
-	}
-
-	return t.RenderResource("AWS::EC2::VPCDHCPOptionsAssociation", *e.Name, tf)
-}
