@@ -22,7 +22,7 @@ import (
 	"reflect"
 	"testing"
 
-	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2020-06-01/compute"
+	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2022-08-01/compute"
 	"github.com/Azure/go-autorest/autorest/to"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -44,6 +44,15 @@ func (c *mockVMScaleSetsClient) List(ctx context.Context, resourceGroupName stri
 	return c.vmsses, nil
 }
 
+func (c *mockVMScaleSetsClient) Get(ctx context.Context, resourceGroupName string, vmssName string) (*compute.VirtualMachineScaleSet, error) {
+	for _, vmss := range c.vmsses {
+		if *vmss.Name == vmssName {
+			return &vmss, nil
+		}
+	}
+	return nil, nil
+}
+
 func (c *mockVMScaleSetsClient) Delete(ctx context.Context, resourceGroupName, vmssName string) error {
 	return fmt.Errorf("unimplemented")
 }
@@ -72,6 +81,7 @@ func TestFindEtcdStatus(t *testing.T) {
 			Name: to.StringPtr("d0"),
 			Tags: map[string]*string{
 				TagClusterName:                             to.StringPtr(clusterName),
+				TagNameRolePrefix + TagRoleControlPlane:    to.StringPtr("1"),
 				TagNameRolePrefix + TagRoleMaster:          to.StringPtr("1"),
 				TagNameEtcdClusterPrefix + etcdClusterName: to.StringPtr("a/a,b,c"),
 			},
@@ -80,6 +90,7 @@ func TestFindEtcdStatus(t *testing.T) {
 			Name: to.StringPtr("d1"),
 			Tags: map[string]*string{
 				TagClusterName:                             to.StringPtr(clusterName),
+				TagNameRolePrefix + TagRoleControlPlane:    to.StringPtr("1"),
 				TagNameRolePrefix + TagRoleMaster:          to.StringPtr("1"),
 				TagNameEtcdClusterPrefix + etcdClusterName: to.StringPtr("b/a,b,c"),
 			},
@@ -88,6 +99,7 @@ func TestFindEtcdStatus(t *testing.T) {
 			Name: to.StringPtr("d2"),
 			Tags: map[string]*string{
 				TagClusterName:                             to.StringPtr(clusterName),
+				TagNameRolePrefix + TagRoleControlPlane:    to.StringPtr("1"),
 				TagNameRolePrefix + TagRoleMaster:          to.StringPtr("1"),
 				TagNameEtcdClusterPrefix + etcdClusterName: to.StringPtr("c/a,b,c"),
 			},
@@ -219,7 +231,7 @@ func TestGetCloudGroups(t *testing.T) {
 				Name: masterIG,
 			},
 			Spec: kops.InstanceGroupSpec{
-				Role: kops.InstanceGroupRoleMaster,
+				Role: kops.InstanceGroupRoleControlPlane,
 			},
 		},
 		{
