@@ -19,7 +19,7 @@ package azuretasks
 import (
 	"context"
 
-	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2020-06-01/network"
+	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2022-05-01/network"
 	"github.com/Azure/go-autorest/autorest/to"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/upup/pkg/fi"
@@ -37,8 +37,9 @@ type RouteTable struct {
 }
 
 var (
-	_ fi.Task          = &RouteTable{}
-	_ fi.CompareWithID = &RouteTable{}
+	_ fi.CloudupTask          = &RouteTable{}
+	_ fi.CompareWithID        = &RouteTable{}
+	_ fi.CloudupTaskNormalize = &RouteTable{}
 )
 
 // CompareWithID returns the Name of the VM Scale Set.
@@ -47,8 +48,8 @@ func (r *RouteTable) CompareWithID() *string {
 }
 
 // Find discovers the RouteTable in the cloud provider.
-func (r *RouteTable) Find(c *fi.Context) (*RouteTable, error) {
-	cloud := c.Cloud.(azure.AzureCloud)
+func (r *RouteTable) Find(c *fi.CloudupContext) (*RouteTable, error) {
+	cloud := c.T.Cloud.(azure.AzureCloud)
 	l, err := cloud.RouteTable().List(context.TODO(), *r.ResourceGroup.Name)
 	if err != nil {
 		return nil, err
@@ -66,6 +67,7 @@ func (r *RouteTable) Find(c *fi.Context) (*RouteTable, error) {
 	return &RouteTable{
 		Name:      r.Name,
 		Lifecycle: r.Lifecycle,
+		Shared:    r.Shared,
 		ResourceGroup: &ResourceGroup{
 			Name: r.ResourceGroup.Name,
 		},
@@ -73,10 +75,14 @@ func (r *RouteTable) Find(c *fi.Context) (*RouteTable, error) {
 	}, nil
 }
 
+func (r *RouteTable) Normalize(c *fi.CloudupContext) error {
+	c.T.Cloud.(azure.AzureCloud).AddClusterTags(r.Tags)
+	return nil
+}
+
 // Run implements fi.Task.Run.
-func (r *RouteTable) Run(c *fi.Context) error {
-	c.Cloud.(azure.AzureCloud).AddClusterTags(r.Tags)
-	return fi.DefaultDeltaRunMethod(r, c)
+func (r *RouteTable) Run(c *fi.CloudupContext) error {
+	return fi.CloudupDefaultDeltaRunMethod(r, c)
 }
 
 // CheckChanges returns an error if a change is not allowed.
@@ -99,9 +105,9 @@ func (*RouteTable) CheckChanges(a, e, changes *RouteTable) error {
 // RenderAzure creates or updates a Route Table.
 func (*RouteTable) RenderAzure(t *azure.AzureAPITarget, a, e, changes *RouteTable) error {
 	if a == nil {
-		klog.Infof("Creating a new Route Table with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Creating a new Route Table with name: %s", fi.ValueOf(e.Name))
 	} else {
-		klog.Infof("Updating a Route Table with name: %s", fi.StringValue(e.Name))
+		klog.Infof("Updating a Route Table with name: %s", fi.ValueOf(e.Name))
 	}
 
 	rt := network.RouteTable{
