@@ -29,76 +29,17 @@ import (
 	"k8s.io/kops/upup/pkg/fi/cloudup/azure"
 )
 
-// SubnetID contains the resource ID/names required to construct a subnet ID.
-type SubnetID struct {
-	SubscriptionID     string
-	ResourceGroupName  string
-	VirtualNetworkName string
-	SubnetName         string
-}
-
-// String returns the subnet ID in the path format.
-func (s *SubnetID) String() string {
-	return fmt.Sprintf("/subscriptions/%s/resourceGroups/%s/providers/Microsoft.Network/virtualNetworks/%s/subnets/%s",
-		s.SubscriptionID,
-		s.ResourceGroupName,
-		s.VirtualNetworkName,
-		s.SubnetName)
-}
-
-// ParseSubnetID parses a given subnet ID string and returns a SubnetID.
-func ParseSubnetID(s string) (*SubnetID, error) {
-	l := strings.Split(s, "/")
-	if len(l) != 11 {
-		return nil, fmt.Errorf("malformed format of subnet ID: %s, %d", s, len(l))
-	}
-	return &SubnetID{
-		SubscriptionID:     l[2],
-		ResourceGroupName:  l[4],
-		VirtualNetworkName: l[8],
-		SubnetName:         l[10],
-	}, nil
-}
-
-// loadBalancerID contains the resource ID/names required to construct a loadbalancer ID.
-type loadBalancerID struct {
-	SubscriptionID    string
-	ResourceGroupName string
-	LoadBalancerName  string
-}
-
-// String returns the loadbalancer ID in the path format.
-func (lb *loadBalancerID) String() string {
-	return fmt.Sprintf("/subscriptions/%s/resourceGroups/%s/providers/Microsoft.Network/loadbalancers/%s/backendAddressPools/LoadBalancerBackEnd",
-		lb.SubscriptionID,
-		lb.ResourceGroupName,
-		lb.LoadBalancerName,
-	)
-}
-
-// parseLoadBalancerID parses a given loadbalancer ID string and returns a loadBalancerID.
-func parseLoadBalancerID(lb string) (*loadBalancerID, error) {
-	l := strings.Split(lb, "/")
-	if len(l) != 11 {
-		return nil, fmt.Errorf("malformed format of loadbalancer ID: %s, %d", lb, len(l))
-	}
-	return &loadBalancerID{
-		SubscriptionID:    l[2],
-		ResourceGroupName: l[4],
-		LoadBalancerName:  l[8],
-	}, nil
-}
-
 // VMScaleSet is an Azure VM Scale Set.
 // +kops:fitask
 type VMScaleSet struct {
 	Name      *string
 	Lifecycle fi.Lifecycle
 
-	ResourceGroup  *ResourceGroup
-	VirtualNetwork *VirtualNetwork
-	Subnet         *Subnet
-	StorageProfile *VMScaleSetStorageProfile
+	ResourceGroup             *ResourceGroup
+	VirtualNetwork            *VirtualNetwork
+	Subnet                    *Subnet
+	ApplicationSecurityGroups []*ApplicationSecurityGroup
+	StorageProfile            *VMScaleSetStorageProfile
 	// RequirePublicIP is set to true when VMs require public IPs.
 	RequirePublicIP *bool
 	// LoadBalancer is the Load Balancer object the VMs will use.
@@ -154,7 +95,7 @@ func (s *VMScaleSet) CompareWithID() *string {
 func (s *VMScaleSet) Find(c *fi.CloudupContext) (*VMScaleSet, error) {
 	cloud := c.T.Cloud.(azure.AzureCloud)
 	found, err := cloud.VMScaleSet().Get(context.TODO(), *s.ResourceGroup.Name, *s.Name)
-	if err != nil && !strings.Contains(err.Error(), "ResourceNotFound") {
+	if err != nil && !strings.Contains(err.Error(), "NotFound") {
 		return nil, err
 	}
 	if found == nil {
@@ -173,18 +114,18 @@ func (s *VMScaleSet) Find(c *fi.CloudupContext) (*VMScaleSet, error) {
 		return nil, fmt.Errorf("unexpected number of IP configs found for VM ScaleSet %s: %d", *s.Name, len(ipConfigs))
 	}
 	ipConfig := ipConfigs[0]
-	subnetID, err := ParseSubnetID(*ipConfig.Subnet.ID)
+	subnetID, err := azure.ParseSubnetID(*ipConfig.Subnet.ID)
 	if err != nil {
 		return nil, fmt.Errorf("failed to parse subnet ID %s", *ipConfig.Subnet.ID)
 	}
 
-	var loadBalancerID *loadBalancerID
+	var loadBalancerID *azure.LoadBalancerID
 	if ipConfig.LoadBalancerBackendAddressPools != nil {
 		for _, i := range *ipConfig.LoadBalancerBackendAddressPools {
 			if !strings.Contains(*i.ID, "api") {
 				continue
 			}
-			loadBalancerID, err = parseLoadBalancerID(*i.ID)
+			loadBalancerID, err = azure.ParseLoadBalancerID(*i.ID)
 			if err != nil {
 				return nil, fmt.Errorf("failed to parse loadbalancer ID %s", *ipConfig.Subnet.ID)
 			}
@@ -212,7 +153,7 @@ func (s *VMScaleSet) Find(c *fi.CloudupContext) (*VMScaleSet, error) {
 			Name: to.StringPtr(subnetID.VirtualNetworkName),
 		},
 		Subnet: &Subnet{
-			Name: to.StringPtr(subnetID.SubnetName),
+			ID: ipConfig.Subnet.ID,
 		},
 		StorageProfile: &VMScaleSetStorageProfile{
 			VirtualMachineScaleSetStorageProfile: profile.StorageProfile,
@@ -227,6 +168,13 @@ func (s *VMScaleSet) Find(c *fi.CloudupContext) (*VMScaleSet, error) {
 		Tags:               found.Tags,
 		PrincipalID:        found.Identity.PrincipalID,
 	}
+	if ipConfig.ApplicationSecurityGroups != nil {
+		for _, asg := range *ipConfig.ApplicationSecurityGroups {
+			vmss.ApplicationSecurityGroups = append(vmss.ApplicationSecurityGroups, &ApplicationSecurityGroup{
+				ID: asg.ID,
+			})
+		}
+	}
 	if loadBalancerID != nil {
 		vmss.LoadBalancer = &LoadBalancer{
 			Name: to.StringPtr(loadBalancerID.LoadBalancerName),
@@ -301,18 +249,25 @@ func (s *VMScaleSet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *VMScale
 		},
 	}
 
-	subnetID := SubnetID{
+	subnetID := azure.SubnetID{
 		SubscriptionID:     t.Cloud.SubscriptionID(),
 		ResourceGroupName:  *e.ResourceGroup.Name,
 		VirtualNetworkName: *e.VirtualNetwork.Name,
 		SubnetName:         *e.Subnet.Name,
 	}
+	var asgs []compute.SubResource
+	for _, asg := range e.ApplicationSecurityGroups {
+		asgs = append(asgs, compute.SubResource{
+			ID: asg.ID,
+		})
+	}
 	ipConfigProperties := &compute.VirtualMachineScaleSetIPConfigurationProperties{
 		Subnet: &compute.APIEntityReference{
 			ID: to.StringPtr(subnetID.String()),
 		},
-		Primary:                 to.BoolPtr(true),
-		PrivateIPAddressVersion: compute.IPv4,
+		Primary:                   to.BoolPtr(true),
+		PrivateIPAddressVersion:   compute.IPv4,
+		ApplicationSecurityGroups: &asgs,
 	}
 	if *e.RequirePublicIP {
 		ipConfigProperties.PublicIPAddressConfiguration = &compute.VirtualMachineScaleSetPublicIPAddressConfiguration{
@@ -323,7 +278,7 @@ func (s *VMScaleSet) RenderAzure(t *azure.AzureAPITarget, a, e, changes *VMScale
 		}
 	}
 	if e.LoadBalancer != nil {
-		loadBalancerID := loadBalancerID{
+		loadBalancerID := azure.LoadBalancerID{
 			SubscriptionID:    t.Cloud.SubscriptionID(),
 			ResourceGroupName: *e.ResourceGroup.Name,
 			LoadBalancerName:  *e.LoadBalancer.Name,
