@@ -22,7 +22,6 @@ import (
 
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/klog/v2"
-
 	channelsapi "k8s.io/kops/channels/pkg/api"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/assets"
@@ -47,6 +46,7 @@ import (
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/fitasks"
 	"k8s.io/kops/upup/pkg/fi/utils"
+	"k8s.io/kops/util/pkg/vfs"
 )
 
 // BootstrapChannelBuilder is responsible for handling the addons in channels
@@ -162,7 +162,8 @@ func (b *BootstrapChannelBuilder) Build(c *fi.CloudupModelBuilderContext) error
 
 	if featureflag.UseAddonOperators.Enabled() {
 		ob := &wellknownoperators.Builder{
-			Cluster: b.Cluster,
+			VFSContext: vfs.Context,
+			Cluster:    b.Cluster,
 		}
 
 		addonPackages, clusterAddons, err := ob.Build(b.ClusterAddons)
@@ -405,37 +406,6 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.CloudupModelBuilderContext)
 		}
 	}
 
-	// @check if bootstrap tokens are enabled an if so we can forgo applying
-	// this manifest. For clusters whom are upgrading from RBAC to Node,RBAC the clusterrolebinding
-	// will remain and have to be deleted manually once all the nodes have been upgraded.
-	enableRBACAddon := true
-	if b.UseKopsControllerForNodeBootstrap() {
-		enableRBACAddon = false
-	}
-	if b.Cluster.Spec.KubeAPIServer != nil {
-		if b.Cluster.Spec.KubeAPIServer.EnableBootstrapAuthToken != nil && *b.Cluster.Spec.KubeAPIServer.EnableBootstrapAuthToken {
-			enableRBACAddon = false
-		}
-	}
-
-	if enableRBACAddon {
-		{
-			key := "rbac.addons.k8s.io"
-
-			{
-				location := key + "/k8s-1.8.yaml"
-				id := "k8s-1.8"
-
-				addons.Add(&channelsapi.AddonSpec{
-					Name:     fi.PtrTo(key),
-					Selector: map[string]string{"k8s-addon": key},
-					Manifest: fi.PtrTo(location),
-					Id:       id,
-				})
-			}
-		}
-	}
-
 	{
 		// Adding the kubelet-api-admin binding: this is required when switching to webhook authorization on the kubelet
 		// docs: https://kubernetes.io/docs/reference/access-authn-authz/rbac/#other-component-roles
@@ -455,7 +425,7 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.CloudupModelBuilderContext)
 		}
 	}
 
-	if b.IsKubernetesGTE("1.23") && b.IsKubernetesLT("1.26") &&
+	if b.IsKubernetesLT("1.26") &&
 		(b.Cluster.Spec.GetCloudProvider() == kops.CloudProviderAWS ||
 			b.Cluster.Spec.GetCloudProvider() == kops.CloudProviderGCE) {
 		// AWS and GCE KCM-to-CCM leader migration
@@ -975,22 +945,6 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.CloudupModelBuilderContext)
 		}
 	}
 
-	if b.Cluster.Spec.Networking.Weave != nil {
-		key := "networking.weave"
-
-		{
-			location := key + "/k8s-1.12.yaml"
-			id := "k8s-1.12"
-
-			addons.Add(&channelsapi.AddonSpec{
-				Name:     fi.PtrTo(key),
-				Selector: networkingSelector(),
-				Manifest: fi.PtrTo(location),
-				Id:       id,
-			})
-		}
-	}
-
 	if b.Cluster.Spec.Networking.Flannel != nil {
 		key := "networking.flannel"
 
@@ -1169,21 +1123,19 @@ func (b *BootstrapChannelBuilder) buildAddons(c *fi.CloudupModelBuilderContext)
 			addon.BuildPrune = true
 		}
 
-		if b.Cluster.Spec.ExternalCloudControllerManager != nil {
-			// cloudprovider specific out-of-tree controller
-			{
-				key := "openstack.addons.k8s.io"
+		// cloudprovider specific out-of-tree controller
+		{
+			key := "openstack.addons.k8s.io"
 
-				location := key + "/k8s-1.13.yaml"
-				id := "k8s-1.13-ccm"
+			location := key + "/k8s-1.13.yaml"
+			id := "k8s-1.13-ccm"
 
-				addons.Add(&channelsapi.AddonSpec{
-					Name:     fi.PtrTo(key),
-					Manifest: fi.PtrTo(location),
-					Selector: map[string]string{"k8s-addon": key},
-					Id:       id,
-				})
-			}
+			addons.Add(&channelsapi.AddonSpec{
+				Name:     fi.PtrTo(key),
+				Manifest: fi.PtrTo(location),
+				Selector: map[string]string{"k8s-addon": key},
+				Id:       id,
+			})
 		}
 	}
 
