@@ -66,6 +66,7 @@ type DOCloud interface {
 	DropletActionService() godo.DropletActionsService
 	VolumeService() godo.StorageService
 	VolumeActionService() godo.StorageActionsService
+	KeysService() godo.KeysService
 	LoadBalancersService() godo.LoadBalancersService
 	DomainService() godo.DomainsService
 	ActionsService() godo.ActionsService
@@ -209,6 +210,11 @@ func (c *doCloudImplementation) DNS() (dnsprovider.Interface, error) {
 	return provider, nil
 }
 
+// KeysService returns an implementation of godo.KeysService
+func (c *doCloudImplementation) KeysService() godo.KeysService {
+	return c.Client.Keys
+}
+
 // Volumes returns an implementation of godo.StorageService
 func (c *doCloudImplementation) VolumeService() godo.StorageService {
 	return c.Client.Storage
