@@ -17,6 +17,7 @@ limitations under the License.
 package gcetasks
 
 import (
+	"context"
 	"testing"
 
 	gcemock "k8s.io/kops/cloudmock/gce"
@@ -24,38 +25,40 @@ import (
 )
 
 func TestStorageBucketIAM(t *testing.T) {
+	ctx := context.TODO()
+
 	project := "testproject"
 	region := "us-test1"
 
 	cloud := gcemock.InstallMockGCECloud(region, project)
 
 	// We define a function so we can rebuild the tasks, because we modify in-place when running
-	buildTasks := func() map[string]fi.Task {
+	buildTasks := func() map[string]fi.CloudupTask {
 		binding := &StorageBucketIAM{
 			Lifecycle: fi.LifecycleSync,
 
-			Bucket: fi.String("bucket1"),
-			Member: fi.String("serviceAccount:foo@testproject.iam.gserviceaccount.com"),
-			Role:   fi.String("roles/owner"),
+			Bucket: fi.PtrTo("bucket1"),
+			Member: fi.PtrTo("serviceAccount:foo@testproject.iam.gserviceaccount.com"),
+			Role:   fi.PtrTo("roles/owner"),
 		}
 
-		return map[string]fi.Task{
+		return map[string]fi.CloudupTask{
 			"binding": binding,
 		}
 	}
 
 	{
 		allTasks := buildTasks()
-		checkHasChanges(t, cloud, allTasks)
+		checkHasChanges(t, ctx, cloud, allTasks)
 	}
 
 	{
 		allTasks := buildTasks()
-		runTasks(t, cloud, allTasks)
+		runTasks(t, ctx, cloud, allTasks)
 	}
 
 	{
 		allTasks := buildTasks()
-		checkNoChanges(t, cloud, allTasks)
+		checkNoChanges(t, ctx, cloud, allTasks)
 	}
 }
