@@ -52,9 +52,12 @@ const (
 	defaultMasterMachineTypeHetzner  = "cx21"
 	defaultMasterMachineTypeScaleway = "DEV1-M"
 
-	defaultDOImage       = "ubuntu-20-04-x64"
-	defaultHetznerImage  = "ubuntu-20.04"
-	defaultScalewayImage = "ubuntu_focal"
+	defaultDOImageFocal       = "ubuntu-20-04-x64"
+	defaultHetznerImageFocal  = "ubuntu-20.04"
+	defaultScalewayImageFocal = "ubuntu_focal"
+	defaultDOImageJammy       = "ubuntu-22-04-x64"
+	defaultHetznerImageJammy  = "ubuntu-22.04"
+	defaultScalewayImageJammy = "ubuntu_jammy"
 )
 
 // TODO: this hardcoded list can be replaced with DescribeInstanceTypes' DedicatedHostsSupported field
@@ -255,7 +258,11 @@ func PopulateInstanceGroupSpec(cluster *kops.Cluster, input *kops.InstanceGroup,
 
 	// We include the NodeLabels in the userdata even for Kubernetes 1.16 and later so that
 	// rolling update will still replace nodes when they change.
-	igKubeletConfig.NodeLabels = nodelabels.BuildNodeLabels(cluster, ig)
+	nodeLabels, err := nodelabels.BuildNodeLabels(cluster, ig)
+	if err != nil {
+		return nil, fmt.Errorf("error building node labels: %w", err)
+	}
+	igKubeletConfig.NodeLabels = nodeLabels
 
 	useSecureKubelet := fi.ValueOf(igKubeletConfig.AnonymousAuth)
 
