@@ -25,6 +25,7 @@ import (
 	iam "github.com/scaleway/scaleway-sdk-go/api/iam/v1alpha1"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/api/lb/v1"
+	"github.com/scaleway/scaleway-sdk-go/api/marketplace/v2"
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/klog/v2"
@@ -39,8 +40,9 @@ import (
 const (
 	TagClusterName           = "noprefix=kops.k8s.io/cluster"
 	TagInstanceGroup         = "noprefix=kops.k8s.io/instance-group"
-	TagNameRolePrefix        = "noprefix=kops.k8s.io/role"
 	TagNameEtcdClusterPrefix = "noprefix=kops.k8s.io/etcd"
+	TagNeedsUpdate           = "noprefix=kops.k8s.io/needs-update"
+	TagNameRolePrefix        = "noprefix=kops.k8s.io/role"
 	TagRoleControlPlane      = "ControlPlane"
 	TagRoleWorker            = "Node"
 	KopsUserAgentPrefix      = "kubernetes-kops/"
@@ -60,6 +62,7 @@ type ScwCloud interface {
 	IamService() *iam.API
 	InstanceService() *instance.API
 	LBService() *lb.ZonedAPI
+	MarketplaceService() *marketplace.API
 
 	DeleteGroup(group *cloudinstances.CloudInstanceGroup) error
 	DeleteInstance(i *cloudinstances.CloudInstance) error
@@ -94,10 +97,11 @@ type scwCloudImplementation struct {
 	dns    dnsprovider.Interface
 	tags   map[string]string
 
-	domainAPI   *domain.API
-	iamAPI      *iam.API
-	instanceAPI *instance.API
-	lbAPI       *lb.ZonedAPI
+	domainAPI      *domain.API
+	iamAPI         *iam.API
+	instanceAPI    *instance.API
+	lbAPI          *lb.ZonedAPI
+	marketplaceAPI *marketplace.API
 }
 
 // NewScwCloud returns a Cloud with a Scaleway Client using the env vars SCW_PROFILE or
@@ -134,25 +138,21 @@ func NewScwCloud(tags map[string]string) (ScwCloud, error) {
 	}
 
 	return &scwCloudImplementation{
-		client:      scwClient,
-		region:      region,
-		zone:        zone,
-		dns:         dns.NewProvider(domain.NewAPI(scwClient)),
-		tags:        tags,
-		domainAPI:   domain.NewAPI(scwClient),
-		iamAPI:      iam.NewAPI(scwClient),
-		instanceAPI: instance.NewAPI(scwClient),
-		lbAPI:       lb.NewZonedAPI(scwClient),
+		client:         scwClient,
+		region:         region,
+		zone:           zone,
+		dns:            dns.NewProvider(domain.NewAPI(scwClient)),
+		tags:           tags,
+		domainAPI:      domain.NewAPI(scwClient),
+		iamAPI:         iam.NewAPI(scwClient),
+		instanceAPI:    instance.NewAPI(scwClient),
+		lbAPI:          lb.NewZonedAPI(scwClient),
+		marketplaceAPI: marketplace.NewAPI(scwClient),
 	}, nil
 }
 
 func (s *scwCloudImplementation) ClusterName(tags []string) string {
-	for _, tag := range tags {
-		if strings.HasPrefix(tag, TagClusterName) {
-			return strings.TrimPrefix(tag, TagClusterName+"=")
-		}
-	}
-	return ""
+	return ClusterNameFromTags(tags)
 }
 
 func (s *scwCloudImplementation) DNS() (dnsprovider.Interface, error) {
@@ -191,6 +191,10 @@ func (s *scwCloudImplementation) LBService() *lb.ZonedAPI {
 	return s.lbAPI
 }
 
+func (s *scwCloudImplementation) MarketplaceService() *marketplace.API {
+	return s.marketplaceAPI
+}
+
 func (s *scwCloudImplementation) DeleteGroup(group *cloudinstances.CloudInstanceGroup) error {
 	toDelete := append(group.NeedUpdate, group.Ready...)
 	for _, cloudInstance := range toDelete {
@@ -345,13 +349,7 @@ func findServerGroups(s *scwCloudImplementation, clusterName string) (map[string
 
 	serverGroups := make(map[string][]*instance.Server)
 	for _, server := range servers {
-		igName := ""
-		for _, tag := range server.Tags {
-			if strings.HasPrefix(tag, TagInstanceGroup) {
-				igName = strings.TrimPrefix(tag, TagInstanceGroup+"=")
-				break
-			}
-		}
+		igName := InstanceGroupNameFromTags(server.Tags)
 		serverGroups[igName] = append(serverGroups[igName], server)
 	}
 
@@ -370,17 +368,18 @@ func buildCloudGroup(ig *kops.InstanceGroup, sg []*instance.Server, nodeMap map[
 
 	for _, server := range sg {
 		status := cloudinstances.CloudInstanceStatusUpToDate
+		for _, tag := range server.Tags {
+			if tag == TagNeedsUpdate {
+				status = cloudinstances.CloudInstanceStatusNeedsUpdate
+			}
+		}
 		cloudInstance, err := cloudInstanceGroup.NewCloudInstance(server.ID, status, nodeMap[server.ID])
 		if err != nil {
 			return nil, fmt.Errorf("failed to create cloud instance for server %s(%s): %w", server.Name, server.ID, err)
 		}
 		cloudInstance.State = cloudinstances.State(server.State)
 		cloudInstance.MachineType = server.CommercialType
-		for _, tag := range server.Tags {
-			if strings.HasPrefix(tag, TagNameRolePrefix) {
-				cloudInstance.Roles = append(cloudInstance.Roles, strings.TrimPrefix(tag, TagNameRolePrefix))
-			}
-		}
+		cloudInstance.Roles = append(cloudInstance.Roles, InstanceRoleFromTags(server.Tags))
 		if server.PrivateIP != nil {
 			cloudInstance.PrivateIP = *server.PrivateIP
 		}
@@ -534,7 +533,7 @@ func (s *scwCloudImplementation) DeleteLoadBalancer(loadBalancer *lb.LB) error {
 }
 
 func (s *scwCloudImplementation) DeleteServer(server *instance.Server) error {
-	_, err := s.instanceAPI.GetServer(&instance.GetServerRequest{
+	srv, err := s.instanceAPI.GetServer(&instance.GetServerRequest{
 		Zone:     s.zone,
 		ServerID: server.ID,
 	})
@@ -546,6 +545,28 @@ func (s *scwCloudImplementation) DeleteServer(server *instance.Server) error {
 		return err
 	}
 
+	// We detach the etcd volumes
+	for _, volume := range srv.Server.Volumes {
+		volumeResponse, err := s.instanceAPI.GetVolume(&instance.GetVolumeRequest{
+			Zone:     s.zone,
+			VolumeID: volume.ID,
+		})
+		if err != nil {
+			return fmt.Errorf("delete server %s: getting infos for volume %s", server.ID, volume.ID)
+		}
+		for _, tag := range volumeResponse.Volume.Tags {
+			if strings.HasPrefix(tag, TagNameEtcdClusterPrefix) {
+				_, err = s.instanceAPI.DetachVolume(&instance.DetachVolumeRequest{
+					Zone:     s.zone,
+					VolumeID: volume.ID,
+				})
+				if err != nil {
+					return fmt.Errorf("delete server %s: detaching volume %s", server.ID, volume.ID)
+				}
+			}
+		}
+	}
+
 	// We terminate the server. This stops and deletes the machine immediately
 	_, err = s.instanceAPI.ServerAction(&instance.ServerActionRequest{
 		Zone:     s.zone,
@@ -553,7 +574,7 @@ func (s *scwCloudImplementation) DeleteServer(server *instance.Server) error {
 		Action:   instance.ServerActionTerminate,
 	})
 	if err != nil && !is404Error(err) {
-		return fmt.Errorf("delete server %s: error terminating instance: %w", server.ID, err)
+		return fmt.Errorf("delete server %s: terminating instance: %w", server.ID, err)
 	}
 
 	_, err = s.instanceAPI.WaitForServer(&instance.WaitForServerRequest{
@@ -561,7 +582,7 @@ func (s *scwCloudImplementation) DeleteServer(server *instance.Server) error {
 		Zone:     s.zone,
 	})
 	if err != nil && !is404Error(err) {
-		return fmt.Errorf("delete server %s: error waiting for instance after termination: %w", server.ID, err)
+		return fmt.Errorf("delete server %s: waiting for instance after termination: %w", server.ID, err)
 	}
 
 	return nil
