@@ -62,6 +62,7 @@ import (
 	"k8s.io/kops/pkg/wellknownports"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
+	"k8s.io/kops/upup/pkg/fi/cloudup/azure"
 	"k8s.io/kops/upup/pkg/fi/cloudup/do"
 	"k8s.io/kops/upup/pkg/fi/cloudup/gce"
 	gcetpm "k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm"
@@ -90,7 +91,6 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	dest["KubeObjectToApplyYAML"] = kubemanifest.KubeObjectToApplyYAML
 
 	dest["SharedVPC"] = tf.SharedVPC
-	dest["UseBootstrapTokens"] = tf.UseBootstrapTokens
 	// Remember that we may be on a different arch from the target.  Hard-code for now.
 	dest["replace"] = func(s, find, replace string) string {
 		return strings.Replace(s, find, replace, -1)
@@ -170,9 +170,6 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	dest["ProxyEnv"] = tf.ProxyEnv
 
 	dest["KopsSystemEnv"] = tf.KopsSystemEnv
-	dest["UseKopsControllerForNodeBootstrap"] = func() bool {
-		return tf.UseKopsControllerForNodeBootstrap()
-	}
 
 	dest["DO_TOKEN"] = func() string {
 		return os.Getenv("DIGITALOCEAN_ACCESS_TOKEN")
@@ -189,7 +186,7 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	}
 
 	dest["OPENSTACK_CONF"] = func() string {
-		lines := openstack.MakeCloudConfig(cluster.Spec)
+		lines := openstack.MakeCloudConfig(cluster.Spec.CloudProvider.Openstack)
 		return "[global]\n" + strings.Join(lines, "\n") + "\n"
 	}
 
@@ -324,20 +321,6 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 		dest["FlannelBackendType"] = func() string { return flannelBackendType }
 	}
 
-	if cluster.Spec.Networking.Weave != nil {
-		weavesecretString := ""
-		weavesecret, _ := secretStore.Secret("weavepassword")
-		if weavesecret != nil {
-			weavesecretString, err = weavesecret.AsString()
-			if err != nil {
-				return err
-			}
-			klog.V(4).Info("Weave secret function successfully registered")
-		}
-
-		dest["WeaveSecret"] = func() string { return weavesecretString }
-	}
-
 	dest["CloudLabels"] = func() string {
 		labels := []string{
 			fmt.Sprintf("KubernetesCluster=%s", cluster.ObjectMeta.Name),
@@ -415,6 +398,13 @@ func (tf *TemplateFunctions) AddTo(dest template.FuncMap, secretStore fi.SecretS
 	dest["KopsFeatureEnabled"] = tf.kopsFeatureEnabled
 	dest["KopsVersion"] = func() string { return kopsroot.KOPS_RELEASE_VERSION }
 
+	dest["ContainerdSELinuxEnabled"] = func() bool {
+		if cluster.Spec.Containerd != nil {
+			return cluster.Spec.Containerd.SeLinuxEnabled
+		}
+		return false
+	}
+
 	return nil
 }
 
@@ -452,14 +442,27 @@ func (tf *TemplateFunctions) GetInstanceGroup(name string) (*kops.InstanceGroup,
 	return ig, nil
 }
 
-// ControlPlaneControllerReplicas returns the amount of replicas for a controllers that should run in the cluster
-// If the cluster has a highly available control plane, this function will return 2, if it has 1 control plane node, it will return 1
-// deployOnWorkersIfExternalPermissons should be true if a controller runs on worker nodes when external IAM permissions is enabled for the cluster.
-// In this case it is assumed that it can run 2 replicas.
+// ControlPlaneControllerReplicas returns the amount of replicas for a controllers that should run in the cluster.
+// deployOnWorkersIfExternalPermissons indicates if a controller can run on worker nodes when external IAM permissions is enabled for the cluster.
 func (tf *TemplateFunctions) ControlPlaneControllerReplicas(deployOnWorkersIfExternalPermissions bool) int {
+	// Check if we are running on worker nodes
 	if deployOnWorkersIfExternalPermissions && tf.Cluster.Spec.IAM != nil && fi.ValueOf(tf.Cluster.Spec.IAM.UseServiceAccountExternalPermissions) {
-		return 2
+		// If we only have one control plane node, we still only run one instance,
+		// because most controllers still need a lease from the control plane,
+		// so we can't get higher availability by running multiple instances
+		// (though we would get faster time-to-recovery)
+		//
+		// This also supports running with one control-plane node and one worker node,
+		// and we may have spreading constraints that prevent both pods running on
+		// the same worker node.  Issue #15852
+		if tf.HasHighlyAvailableControlPlane() {
+			return 2
+		}
+		return 1
 	}
+
+	// If the cluster has a highly available control plane, we should run two instances of the controller,
+	// otherwise we run one 1.
 	if tf.HasHighlyAvailableControlPlane() {
 		return 2
 	}
@@ -656,15 +659,15 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 	config := &kopscontrollerconfig.Options{
 		ClusterName: cluster.Name,
 		Cloud:       string(cluster.Spec.GetCloudProvider()),
-		ConfigBase:  cluster.Spec.ConfigBase,
-		SecretStore: cluster.Spec.SecretStore,
+		ConfigBase:  cluster.Spec.ConfigStore.Base,
+		SecretStore: cluster.Spec.ConfigStore.Secrets,
 	}
 
 	if featureflag.CacheNodeidentityInfo.Enabled() {
 		config.CacheNodeidentityInfo = true
 	}
 
-	if tf.UseKopsControllerForNodeBootstrap() {
+	{
 		certNames := []string{"kubelet", "kubelet-server"}
 		signingCAs := []string{fi.CertificateIDCA}
 		if apiModel.UseCiliumEtcd(cluster) {
@@ -746,6 +749,11 @@ func (tf *TemplateFunctions) KopsControllerConfig() (string, error) {
 		case kops.CloudProviderScaleway:
 			config.Server.Provider.Scaleway = &scaleway.ScalewayVerifierOptions{}
 
+		case kops.CloudProviderAzure:
+			config.Server.Provider.Azure = &azure.AzureVerifierOptions{
+				ClusterName: tf.ClusterName(),
+			}
+
 		default:
 			return "", fmt.Errorf("unsupported cloud provider %s", cluster.Spec.GetCloudProvider())
 		}
