@@ -19,9 +19,9 @@ package fi
 // HasAddress is implemented by elastic/floating IP addresses in order to include
 // relevant dynamically allocated addresses in the api-server's server TLS certificate.
 type HasAddress interface {
-	Task
+	Task[CloudupSubContext]
 	// IsForAPIServer indicates whether the implementation provides an address that needs to be added to the api-server server certificate.
 	IsForAPIServer() bool
 	// FindIPAddress returns the address associated with the implementor.  If there is no address, returns (nil, nil).
-	FindAddresses(context *Context) ([]string, error)
+	FindAddresses(context *CloudupContext) ([]string, error)
 }
