@@ -19,20 +19,17 @@ package local
 import (
 	"os/exec"
 
-	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
 )
 
 type LocalTarget struct {
-	CacheDir   string
-	Cloud      fi.Cloud
-	InstanceID string
-	Cluster    *kops.Cluster
+	CacheDir string
+	Cloud    fi.Cloud
 }
 
-var _ fi.Target = &LocalTarget{}
+var _ fi.NodeupTarget = &LocalTarget{}
 
-func (t *LocalTarget) Finish(taskMap map[string]fi.Task) error {
+func (t *LocalTarget) Finish(taskMap map[string]fi.NodeupTask) error {
 	return nil
 }
 
@@ -41,6 +38,10 @@ func (t *LocalTarget) ProcessDeletions() bool {
 	return true
 }
 
+func (t *LocalTarget) DefaultCheckExisting() bool {
+	return true
+}
+
 // CombinedOutput is a helper function that executes a command, returning stdout & stderr combined
 func (t *LocalTarget) CombinedOutput(args []string) ([]byte, error) {
 	c := exec.Command(args[0], args[1:]...)
