@@ -49,9 +49,9 @@ func (p *Prefix) String() string {
 	return fmt.Sprintf("Prefix: %s", p.Name)
 }
 
-func (e *Prefix) Find(c *fi.Context) (*Prefix, error) {
-	if c.Cluster.Spec.GetCloudProvider() != kops.CloudProviderAWS {
-		return nil, fmt.Errorf("unsupported cloud provider: %s", c.Cluster.Spec.GetCloudProvider())
+func (e *Prefix) Find(c *fi.NodeupContext) (*Prefix, error) {
+	if c.T.BootConfig.CloudProvider != kops.CloudProviderAWS {
+		return nil, fmt.Errorf("unsupported cloud provider: %s", c.T.BootConfig.CloudProvider)
 	}
 
 	mac, err := getInstanceMetadataFirstValue("mac")
@@ -74,8 +74,8 @@ func (e *Prefix) Find(c *fi.Context) (*Prefix, error) {
 	return actual, nil
 }
 
-func (e *Prefix) Run(c *fi.Context) error {
-	return fi.DefaultDeltaRunMethod(e, c)
+func (e *Prefix) Run(c *fi.NodeupContext) error {
+	return fi.NodeupDefaultDeltaRunMethod(e, c)
 }
 
 func (_ *Prefix) CheckChanges(a, e, changes *Prefix) error {
@@ -94,13 +94,13 @@ func (_ *Prefix) RenderLocal(t *local.LocalTarget, a, e, changes *Prefix) error
 	}
 
 	response, err := t.Cloud.(awsup.AWSCloud).EC2().AssignIpv6Addresses(&ec2.AssignIpv6AddressesInput{
-		Ipv6PrefixCount:    fi.Int64(1),
-		NetworkInterfaceId: fi.String(interfaceId),
+		Ipv6PrefixCount:    fi.PtrTo(int64(1)),
+		NetworkInterfaceId: fi.PtrTo(interfaceId),
 	})
 	if err != nil {
 		return fmt.Errorf("failed to assign prefix: %w", err)
 	}
-	klog.V(2).Infof("assigned prefix to primary network interface: %q", fi.StringValue(response.AssignedIpv6Prefixes[0]))
+	klog.V(2).Infof("assigned prefix to primary network interface: %q", fi.ValueOf(response.AssignedIpv6Prefixes[0]))
 
 	return nil
 }
