@@ -32,15 +32,15 @@ type PullImageTask struct {
 }
 
 var (
-	_ fi.Task            = &PullImageTask{}
-	_ fi.HasDependencies = &PullImageTask{}
+	_ fi.NodeupTask            = &PullImageTask{}
+	_ fi.NodeupHasDependencies = &PullImageTask{}
 )
 
-func (t *PullImageTask) GetDependencies(tasks map[string]fi.Task) []fi.Task {
+func (t *PullImageTask) GetDependencies(tasks map[string]fi.NodeupTask) []fi.NodeupTask {
 	// ImagePullTask depends on the container runtime service to ensure we
 	// sideload images after the container runtime is completely updated and
 	// configured.
-	var deps []fi.Task
+	var deps []fi.NodeupTask
 	for _, v := range tasks {
 		if svc, ok := v.(*Service); ok && svc.Name == containerdService {
 			deps = append(deps, v)
@@ -59,7 +59,7 @@ func (t *PullImageTask) GetName() *string {
 	return &t.Name
 }
 
-func (e *PullImageTask) Run(c *fi.Context) error {
+func (e *PullImageTask) Run(c *fi.NodeupContext) error {
 	runtime := e.Runtime
 	if runtime != "docker" && runtime != "containerd" {
 		return fmt.Errorf("no runtime specified")
