@@ -31,24 +31,22 @@ import (
 )
 
 type VFSSecretStore struct {
+	VFSSecretStoreReader
 	cluster *kops.Cluster
-	basedir vfs.Path
 }
 
 var _ fi.SecretStore = &VFSSecretStore{}
 
 func NewVFSSecretStore(cluster *kops.Cluster, basedir vfs.Path) fi.SecretStore {
 	c := &VFSSecretStore{
+		VFSSecretStoreReader: VFSSecretStoreReader{
+			basedir: basedir,
+		},
 		cluster: cluster,
-		basedir: basedir,
 	}
 	return c
 }
 
-func (c *VFSSecretStore) VFSPath() vfs.Path {
-	return c.basedir
-}
-
 func (c *VFSSecretStore) MirrorTo(ctx context.Context, basedir vfs.Path) error {
 	if basedir.Path() == c.basedir.Path() {
 		klog.V(2).Infof("Skipping mirror of secret store from %q to %q (same path)", c.basedir, basedir)
@@ -80,7 +78,7 @@ func (c *VFSSecretStore) MirrorTo(ctx context.Context, basedir vfs.Path) error {
 
 		klog.Infof("mirroring secret %s -> %s", name, p)
 
-		err = createSecret(secret, p, acl, true)
+		err = createSecret(ctx, secret, p, acl, true)
 		if err != nil {
 			return fmt.Errorf("error writing secret %q for mirror: %v", name, err)
 		}
@@ -89,23 +87,6 @@ func (c *VFSSecretStore) MirrorTo(ctx context.Context, basedir vfs.Path) error {
 	return nil
 }
 
-func BuildVfsSecretPath(basedir vfs.Path, name string) vfs.Path {
-	return basedir.Join(name)
-}
-
-func (c *VFSSecretStore) buildSecretPath(name string) vfs.Path {
-	return BuildVfsSecretPath(c.basedir, name)
-}
-
-func (c *VFSSecretStore) FindSecret(id string) (*fi.Secret, error) {
-	p := c.buildSecretPath(id)
-	s, err := c.loadSecret(p)
-	if err != nil {
-		return nil, err
-	}
-	return s, nil
-}
-
 // DeleteSecret implements fi.SecretStore DeleteSecret
 func (c *VFSSecretStore) DeleteSecret(name string) error {
 	p := c.buildSecretPath(name)
@@ -128,20 +109,7 @@ func (c *VFSSecretStore) ListSecrets() ([]string, error) {
 	return ids, nil
 }
 
-func (c *VFSSecretStore) Secret(id string) (*fi.Secret, error) {
-	s, err := c.FindSecret(id)
-	if err != nil {
-		return nil, err
-	}
-	if s == nil {
-		return nil, fmt.Errorf("secret %q not found", id)
-	}
-	return s, nil
-}
-
-func (c *VFSSecretStore) GetOrCreateSecret(id string, secret *fi.Secret) (*fi.Secret, bool, error) {
-	ctx := context.TODO()
-
+func (c *VFSSecretStore) GetOrCreateSecret(ctx context.Context, id string, secret *fi.Secret) (*fi.Secret, bool, error) {
 	p := c.buildSecretPath(id)
 
 	for i := 0; i < 2; i++ {
@@ -159,7 +127,7 @@ func (c *VFSSecretStore) GetOrCreateSecret(id string, secret *fi.Secret) (*fi.Se
 			return nil, false, err
 		}
 
-		err = createSecret(secret, p, acl, false)
+		err = createSecret(ctx, secret, p, acl, false)
 		if err != nil {
 			if os.IsExist(err) && i == 0 {
 				klog.Infof("Got already-exists error when writing secret; likely due to concurrent creation.  Will retry")
@@ -175,7 +143,7 @@ func (c *VFSSecretStore) GetOrCreateSecret(id string, secret *fi.Secret) (*fi.Se
 	}
 
 	// Make double-sure it round-trips
-	s, err := c.loadSecret(p)
+	s, err := c.loadSecret(ctx, p)
 	if err != nil {
 		klog.Fatalf("unable to load secret immediately after creation %v: %v", p, err)
 		return nil, false, err
@@ -193,36 +161,21 @@ func (c *VFSSecretStore) ReplaceSecret(id string, secret *fi.Secret) (*fi.Secret
 		return nil, err
 	}
 
-	err = createSecret(secret, p, acl, true)
+	err = createSecret(ctx, secret, p, acl, true)
 	if err != nil {
 		return nil, fmt.Errorf("unable to write secret: %v", err)
 	}
 
 	// Confirm the secret exists
-	s, err := c.loadSecret(p)
+	s, err := c.loadSecret(ctx, p)
 	if err != nil {
 		return nil, fmt.Errorf("unable to load secret immediately after creation %v: %v", p, err)
 	}
 	return s, nil
 }
 
-func (c *VFSSecretStore) loadSecret(p vfs.Path) (*fi.Secret, error) {
-	data, err := p.ReadFile()
-	if err != nil {
-		if os.IsNotExist(err) {
-			return nil, nil
-		}
-	}
-	s := &fi.Secret{}
-	err = json.Unmarshal(data, s)
-	if err != nil {
-		return nil, fmt.Errorf("error parsing secret from %q: %v", p, err)
-	}
-	return s, nil
-}
-
 // createSecret will create the Secret, overwriting an existing secret if replace is true
-func createSecret(s *fi.Secret, p vfs.Path, acl vfs.ACL, replace bool) error {
+func createSecret(ctx context.Context, s *fi.Secret, p vfs.Path, acl vfs.ACL, replace bool) error {
 	data, err := json.Marshal(s)
 	if err != nil {
 		return fmt.Errorf("error serializing secret: %v", err)
@@ -230,7 +183,7 @@ func createSecret(s *fi.Secret, p vfs.Path, acl vfs.ACL, replace bool) error {
 
 	rs := bytes.NewReader(data)
 	if replace {
-		return p.WriteFile(rs, acl)
+		return p.WriteFile(ctx, rs, acl)
 	}
-	return p.CreateFile(rs, acl)
+	return p.CreateFile(ctx, rs, acl)
 }
