@@ -23,7 +23,6 @@ import (
 	"os"
 	"sort"
 	"strings"
-	"sync"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -32,17 +31,13 @@ import (
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/v1alpha2"
 	"k8s.io/kops/pkg/kopscodecs"
-	"k8s.io/kops/pkg/pki"
 	"k8s.io/kops/pkg/sshcredentials"
 	"k8s.io/kops/util/pkg/vfs"
 )
 
 type VFSCAStore struct {
-	basedir vfs.Path
+	VFSKeystoreReader
 	cluster *kops.Cluster
-
-	mutex    sync.Mutex
-	cachedCA *Keyset
 }
 
 var (
@@ -52,7 +47,9 @@ var (
 
 func NewVFSCAStore(cluster *kops.Cluster, basedir vfs.Path) *VFSCAStore {
 	c := &VFSCAStore{
-		basedir: basedir,
+		VFSKeystoreReader: VFSKeystoreReader{
+			basedir: basedir,
+		},
 		cluster: cluster,
 	}
 
@@ -63,68 +60,15 @@ func NewVFSCAStore(cluster *kops.Cluster, basedir vfs.Path) *VFSCAStore {
 func NewVFSSSHCredentialStore(cluster *kops.Cluster, basedir vfs.Path) SSHCredentialStore {
 	// Note currently identical to NewVFSCAStore
 	c := &VFSCAStore{
-		basedir: basedir,
+		VFSKeystoreReader: VFSKeystoreReader{
+			basedir: basedir,
+		},
 		cluster: cluster,
 	}
 
 	return c
 }
 
-func (c *VFSCAStore) VFSPath() vfs.Path {
-	return c.basedir
-}
-
-func (c *VFSCAStore) buildPrivateKeyPoolPath(name string) vfs.Path {
-	return c.basedir.Join("private", name)
-}
-
-func (c *VFSCAStore) parseKeysetYaml(data []byte) (*kops.Keyset, bool, error) {
-	defaultReadVersion := v1alpha2.SchemeGroupVersion.WithKind("Keyset")
-
-	object, gvk, err := kopscodecs.Decode(data, &defaultReadVersion)
-	if err != nil {
-		return nil, false, fmt.Errorf("error parsing keyset: %v", err)
-	}
-
-	keyset, ok := object.(*kops.Keyset)
-	if !ok {
-		return nil, false, fmt.Errorf("object was not a keyset, was a %T", object)
-	}
-
-	if gvk == nil {
-		return nil, false, fmt.Errorf("object did not have GroupVersionKind: %q", keyset.Name)
-	}
-
-	return keyset, gvk.Version != keysetFormatLatest, nil
-}
-
-// loadKeyset loads a Keyset from the path.
-// Returns (nil, nil) if the file is not found
-// Bundles avoid the need for a list-files permission, which can be tricky on e.g. GCE
-func (c *VFSCAStore) loadKeyset(p vfs.Path) (*Keyset, error) {
-	bundlePath := p.Join("keyset.yaml")
-	data, err := bundlePath.ReadFile()
-	if err != nil {
-		if os.IsNotExist(err) {
-			return nil, nil
-		}
-		return nil, fmt.Errorf("unable to read bundle %q: %v", p, err)
-	}
-
-	o, legacyFormat, err := c.parseKeysetYaml(data)
-	if err != nil {
-		return nil, fmt.Errorf("error parsing bundle %q: %v", p, err)
-	}
-
-	keyset, err := parseKeyset(o)
-	if err != nil {
-		return nil, fmt.Errorf("error mapping bundle %q: %v", p, err)
-	}
-
-	keyset.LegacyFormat = legacyFormat
-	return keyset, nil
-}
-
 func (k *Keyset) ToAPIObject(name string) (*kops.Keyset, error) {
 	o := &kops.Keyset{}
 	o.Name = name
@@ -192,7 +136,7 @@ func writeKeysetBundle(ctx context.Context, cluster *kops.Cluster, p vfs.Path, n
 	if err != nil {
 		return err
 	}
-	return p.WriteFile(bytes.NewReader(objectData), acl)
+	return p.WriteFile(ctx, bytes.NewReader(objectData), acl)
 }
 
 // serializeKeysetBundle converts a Keyset bundle to yaml, for writing to VFS.
@@ -211,33 +155,10 @@ func serializeKeysetBundle(o *kops.Keyset) ([]byte, error) {
 	return objectData.Bytes(), nil
 }
 
-func (c *VFSCAStore) FindPrimaryKeypair(name string) (*pki.Certificate, *pki.PrivateKey, error) {
-	return FindPrimaryKeypair(c, name)
-}
-
-var legacyKeysetMappings = map[string]string{
-	// The strange name is because kOps prior to 1.19 used the api-server TLS key for this.
-	"service-account": "master",
-	// Renamed in kOps 1.22
-	"kubernetes-ca": "ca",
-}
-
-func (c *VFSCAStore) FindKeyset(id string) (*Keyset, error) {
-	keys, err := c.findPrivateKeyset(id)
-	if keys == nil || os.IsNotExist(err) {
-		if legacyId := legacyKeysetMappings[id]; legacyId != "" {
-			keys, err = c.findPrivateKeyset(legacyId)
-			if keys != nil {
-				keys.LegacyFormat = true
-			}
-		}
-	}
-
-	return keys, err
-}
-
 // ListKeysets implements CAStore::ListKeysets
 func (c *VFSCAStore) ListKeysets() (map[string]*Keyset, error) {
+	ctx := context.TODO()
+
 	baseDir := c.basedir.Join("private")
 	files, err := baseDir.ReadTree()
 	if err != nil {
@@ -259,7 +180,7 @@ func (c *VFSCAStore) ListKeysets() (map[string]*Keyset, error) {
 		}
 
 		name := tokens[0]
-		loadedKeyset, err := c.loadKeyset(baseDir.Join(name))
+		loadedKeyset, err := c.loadKeyset(ctx, baseDir.Join(name))
 		if err != nil {
 			klog.Warningf("ignoring keyset %q: %w", name, err)
 			continue
@@ -326,7 +247,7 @@ func mirrorSSHCredential(ctx context.Context, cluster *kops.Cluster, basedir vfs
 		return err
 	}
 
-	err = p.WriteFile(bytes.NewReader([]byte(sshCredential.Spec.PublicKey)), acl)
+	err = p.WriteFile(ctx, bytes.NewReader([]byte(sshCredential.Spec.PublicKey)), acl)
 	if err != nil {
 		return fmt.Errorf("error writing %q: %v", p, err)
 	}
@@ -362,40 +283,6 @@ func (c *VFSCAStore) StoreKeyset(ctx context.Context, name string, keyset *Keyse
 	return nil
 }
 
-func (c *VFSCAStore) findPrivateKeyset(id string) (*Keyset, error) {
-	var keys *Keyset
-	var err error
-	if id == CertificateIDCA {
-		c.mutex.Lock()
-		defer c.mutex.Unlock()
-
-		cached := c.cachedCA
-		if cached != nil {
-			return cached, nil
-		}
-
-		keys, err = c.loadKeyset(c.buildPrivateKeyPoolPath(id))
-		if err != nil {
-			return nil, err
-		}
-
-		if keys == nil {
-			klog.Warningf("CA private key was not found")
-			// We no longer generate CA certificates automatically - too race-prone
-		} else {
-			c.cachedCA = keys
-		}
-	} else {
-		p := c.buildPrivateKeyPoolPath(id)
-		keys, err = c.loadKeyset(p)
-		if err != nil {
-			return nil, err
-		}
-	}
-
-	return keys, nil
-}
-
 // AddSSHPublicKey stores an SSH public key
 func (c *VFSCAStore) AddSSHPublicKey(ctx context.Context, pubkey []byte) error {
 	id, err := sshcredentials.Fingerprint(strings.TrimSpace(string(pubkey)))
@@ -410,7 +297,7 @@ func (c *VFSCAStore) AddSSHPublicKey(ctx context.Context, pubkey []byte) error {
 		return err
 	}
 
-	return p.WriteFile(bytes.NewReader(pubkey), acl)
+	return p.WriteFile(ctx, bytes.NewReader(pubkey), acl)
 }
 
 func (c *VFSCAStore) buildSSHPublicKeyPath(id string) vfs.Path {
@@ -420,6 +307,8 @@ func (c *VFSCAStore) buildSSHPublicKeyPath(id string) vfs.Path {
 }
 
 func (c *VFSCAStore) FindSSHPublicKeys() ([]*kops.SSHCredential, error) {
+	ctx := context.TODO()
+
 	p := c.basedir.Join("ssh", "public", "admin")
 
 	files, err := p.ReadDir()
@@ -433,7 +322,7 @@ func (c *VFSCAStore) FindSSHPublicKeys() ([]*kops.SSHCredential, error) {
 	var items []*kops.SSHCredential
 
 	for _, f := range files {
-		data, err := f.ReadFile()
+		data, err := f.ReadFile(ctx)
 		if err != nil {
 			if os.IsNotExist(err) {
 				klog.V(2).Infof("Ignoring not-found issue reading %q", f)
