@@ -114,11 +114,6 @@ func TestFindDistribution(t *testing.T) {
 			err:      fmt.Errorf("unsupported distro: ubuntu-16.04"),
 			expected: Distribution{},
 		},
-		{
-			rootfs:   "ubuntu1804",
-			err:      nil,
-			expected: DistributionUbuntu1804,
-		},
 		{
 			rootfs:   "ubuntu2004",
 			err:      nil,
