@@ -17,12 +17,10 @@ limitations under the License.
 package mirrors
 
 import (
-	"fmt"
 	"net/url"
 	"strings"
 
 	"k8s.io/klog/v2"
-	"k8s.io/kops"
 	"k8s.io/kops/util/pkg/hashing"
 )
 
@@ -33,22 +31,15 @@ type MirroredAsset struct {
 
 // BuildMirroredAsset checks to see if this is a file under the standard base location, and if so constructs some mirror locations
 func BuildMirroredAsset(u *url.URL, hash *hashing.Hash) *MirroredAsset {
-	baseURLString := fmt.Sprintf(defaultKopsMirrorBase, kops.Version)
-	if !strings.HasSuffix(baseURLString, "/") {
-		baseURLString += "/"
-	}
-
 	a := &MirroredAsset{
 		Hash: hash,
 	}
 
-	a.Locations = []string{u.String()}
-	if strings.HasPrefix(u.String(), baseURLString) {
-		if hash == nil {
-			klog.Warningf("not using mirrors for asset %s as it does not have a known hash", u.String())
-		} else {
-			a.Locations = FindUrlMirrors(u.String())
-		}
+	if hash == nil {
+		klog.Warningf("not using mirrors for asset %s as it does not have a known hash", u)
+		a.Locations = []string{u.String()}
+	} else {
+		a.Locations = FindURLMirrors(u.String())
 	}
 
 	return a
