@@ -188,6 +188,22 @@ func (p *MemFSPath) Remove() error {
 	return nil
 }
 
+func (p *MemFSPath) RemoveAll() error {
+	tree, err := p.ReadTree()
+	if err != nil {
+		return err
+	}
+
+	for _, filePath := range tree {
+		err := filePath.Remove()
+		if err != nil {
+			return fmt.Errorf("error removing file %s: %w", filePath, err)
+		}
+	}
+
+	return nil
+}
+
 func (p *MemFSPath) RemoveAllVersions() error {
 	return p.Remove()
 }
