@@ -17,6 +17,7 @@ limitations under the License.
 package vfs
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 	"os"
@@ -29,7 +30,6 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/credentials"
 	"github.com/aws/aws-sdk-go/aws/ec2metadata"
-	"github.com/aws/aws-sdk-go/aws/endpoints"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/s3"
@@ -130,7 +130,7 @@ func getCustomS3Config(endpoint string, region string) (*aws.Config, error) {
 	return s3Config, nil
 }
 
-func (s *S3Context) getDetailsForBucket(bucket string) (*S3BucketDetails, error) {
+func (s *S3Context) getDetailsForBucket(ctx context.Context, bucket string) (*S3BucketDetails, error) {
 	s.mutex.Lock()
 	bucketDetails := s.bucketDetails[bucket]
 	s.mutex.Unlock()
@@ -175,10 +175,6 @@ func (s *S3Context) getDetailsForBucket(bucket string) (*S3BucketDetails, error)
 		klog.V(2).Infof("defaulting region to %q", awsRegion)
 	}
 
-	if err := validateRegion(awsRegion); err != nil {
-		return bucketDetails, err
-	}
-
 	request := &s3.GetBucketLocationInput{
 		Bucket: &bucket,
 	}
@@ -189,12 +185,12 @@ func (s *S3Context) getDetailsForBucket(bucket string) (*S3BucketDetails, error)
 		return bucketDetails, fmt.Errorf("error connecting to S3: %s", err)
 	}
 	// Attempt one GetBucketLocation call the "normal" way (i.e. as the bucket owner)
-	response, err = s3Client.GetBucketLocation(request)
+	response, err = s3Client.GetBucketLocationWithContext(ctx, request)
 
 	// and fallback to brute-forcing if it fails
 	if err != nil {
 		klog.V(2).Infof("unable to get bucket location from region %q; scanning all regions: %v", awsRegion, err)
-		response, err = bruteforceBucketLocation(&awsRegion, request)
+		response, err = bruteforceBucketLocation(ctx, &awsRegion, request)
 	}
 
 	if err != nil {
@@ -221,7 +217,7 @@ func (s *S3Context) getDetailsForBucket(bucket string) (*S3BucketDetails, error)
 	return bucketDetails, nil
 }
 
-func (b *S3BucketDetails) hasServerSideEncryptionByDefault() bool {
+func (b *S3BucketDetails) hasServerSideEncryptionByDefault(ctx context.Context) bool {
 	b.mutex.Lock()
 	defer b.mutex.Unlock()
 
@@ -247,7 +243,7 @@ func (b *S3BucketDetails) hasServerSideEncryptionByDefault() bool {
 
 	klog.V(8).Infof("Calling S3 GetBucketEncryption Bucket=%q", b.name)
 
-	result, err := client.GetBucketEncryption(request)
+	result, err := client.GetBucketEncryptionWithContext(ctx, request)
 	if err != nil {
 		// the following cases might lead to the operation failing:
 		// 1. A deny policy on s3:GetEncryptionConfiguration
@@ -282,7 +278,7 @@ out the first result.
 
 See also: https://docs.aws.amazon.com/goto/WebAPI/s3-2006-03-01/GetBucketLocationRequest
 */
-func bruteforceBucketLocation(region *string, request *s3.GetBucketLocationInput) (*s3.GetBucketLocationOutput, error) {
+func bruteforceBucketLocation(ctx context.Context, region *string, request *s3.GetBucketLocationInput) (*s3.GetBucketLocationOutput, error) {
 	config := &aws.Config{Region: region}
 	config = config.WithCredentialsChainVerboseErrors(true)
 
@@ -306,7 +302,7 @@ func bruteforceBucketLocation(region *string, request *s3.GetBucketLocationInput
 		go func(regionName string) {
 			klog.V(8).Infof("Doing GetBucketLocation in %q", regionName)
 			s3Client := s3.New(session, &aws.Config{Region: aws.String(regionName)})
-			result, bucketError := s3Client.GetBucketLocation(request)
+			result, bucketError := s3Client.GetBucketLocationWithContext(ctx, request)
 			if bucketError == nil {
 				klog.V(8).Infof("GetBucketLocation succeeded in %q", regionName)
 				out <- result
@@ -370,19 +366,6 @@ func getRegionFromMetadata() (string, error) {
 	return metadataRegion, nil
 }
 
-func validateRegion(region string) error {
-	resolver := endpoints.DefaultResolver()
-	partitions := resolver.(endpoints.EnumPartitions).Partitions()
-	for _, p := range partitions {
-		for _, r := range p.Regions() {
-			if r.ID() == region {
-				return nil
-			}
-		}
-	}
-	return fmt.Errorf("%s is not a valid region\nPlease check that your region is formatted correctly (e.g. us-east-1)", region)
-}
-
 func VFSPath(url string) (string, error) {
 	if !s3UrlRegexp.MatchString(url) {
 		return "", fmt.Errorf("%s is not a valid S3 URL", url)
